@@ -96,6 +96,7 @@ SyncthingApplet::SyncthingApplet(QObject *parent, const QVariantList &data)
     , m_hasInternalErrors(false)
     , m_initialized(false)
     , m_showTabTexts(false)
+    , m_showDownloads(false)
     , m_applyingSettingsForWizard(false)
 {
     // configure connection
@@ -110,7 +111,6 @@ SyncthingApplet::SyncthingApplet(QObject *parent, const QVariantList &data)
 
     m_sortFilterDirModel.sort(0, Qt::AscendingOrder);
     m_sortFilterDevModel.sort(0, Qt::AscendingOrder);
-    qmlRegisterUncreatableMetaObject(Data::staticMetaObject, "martchus.syncthingplasmoid", 0, 6, "Data", QStringLiteral("only enums"));
 }
 
 SyncthingApplet::~SyncthingApplet()
@@ -189,7 +189,7 @@ void SyncthingApplet::init()
     // apply settings and connect according to settings
     const auto palette = paletteFromTheme(m_theme);
     setBrightColors(isPaletteDark(palette));
-    IconManager::instance().setPalette(palette);
+    m_iconManager.setPalette(palette);
     handleSettingsChanged();
     if (c.readEntry<>("preferIconsFromTheme", false)) {
         Data::setForkAwesomeThemeOverrides();
@@ -215,7 +215,7 @@ void SyncthingApplet::initEngine(QObject *object)
         return;
     }
     const auto color = m_theme.color(Plasma::Theme::TextColor, Plasma::Theme::NormalColorGroup);
-    m_imageProvider = new QtForkAwesome::QuickImageProvider(QtForkAwesome::Renderer::global(), color);
+    m_imageProvider = new QtForkAwesome::QuickImageProvider(m_iconManager.forkAwesomeRenderer(), color);
     connect(engine, &QObject::destroyed, this, &SyncthingApplet::handleImageProviderDestroyed); // engine has ownership over image provider
     engine->addImageProvider(QStringLiteral("fa"), m_imageProvider);
 }
@@ -225,6 +225,20 @@ QIcon SyncthingApplet::statusIcon() const
     return m_statusInfo.statusIcon();
 }
 
+QString SyncthingApplet::connectButtonState() const
+{
+    switch (m_connection.status()) {
+    case Data::SyncthingStatus::Disconnected:
+        return m_connection.isConnecting() ? QStringLiteral("connecting") : QStringLiteral("disconnected");
+    case Data::SyncthingStatus::Reconnecting:
+        return QStringLiteral("connecting");
+    case Data::SyncthingStatus::Paused:
+        return QStringLiteral("paused");
+    default:
+        return QStringLiteral("idle");
+    }
+}
+
 QString SyncthingApplet::incomingTraffic() const
 {
     return trafficString(m_connection.totalIncomingTraffic(), m_connection.totalIncomingRate());
@@ -346,6 +360,22 @@ void SyncthingApplet::updateStatusIconAndTooltip()
     emit connectionStatusChanged();
 }
 
+void SyncthingApplet::triggerConnectButtonAction()
+{
+    switch (m_connection.status()) {
+    case Data::SyncthingStatus::Disconnected:
+        m_connection.connect();
+        break;
+    case Data::SyncthingStatus::Reconnecting:
+        break;
+    case Data::SyncthingStatus::Paused:
+        m_connection.resumeAllDevs();
+        break;
+    default:
+        m_connection.pauseAllDevs();
+    }
+}
+
 #if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 void SyncthingApplet::handleRelevantControlsChanged(bool visible, int tabIndex)
 {
@@ -666,7 +696,7 @@ void SyncthingApplet::handleThemeChanged()
     // return to the event loop before setting the new theme color; otherwise Qt Quick does not update the images
     QTimer::singleShot(0, this, [this] {
         const auto palette = paletteFromTheme(m_theme);
-        IconManager::instance().setPalette(palette);
+        m_iconManager.setPalette(palette);
         setBrightColors(isPaletteDark(palette));
         if (m_imageProvider) {
             m_imageProvider->setDefaultColor(m_theme.color(Plasma::Theme::TextColor, Plasma::Theme::NormalColorGroup));
@@ -694,7 +724,8 @@ void SyncthingApplet::applySettings(int changeConnectionIndex)
     // apply appearance settings
     setSize(config.readEntry<QSize>("size", QSize(25, 25)));
     setShowingTabTexts(config.readEntry<bool>("showTabTexts", false));
-    IconManager::instance().applySettings(&settings.icons.status, nullptr, settings.icons.usePaletteForStatus, false);
+    setShowingDownloads(config.readEntry<bool>("showDownloads", false));
+    m_iconManager.applySettings(&settings.icons.status, nullptr, settings.icons.usePaletteForStatus, false);
 
     // restore selected states
     // note: The settings dialog writes this to the Plasmoid's config like the other settings. However, it
