@@ -3,10 +3,18 @@
 
 #include "./global.h"
 
+#include <QJsonArray>
 #include <QString>
 
+#include <optional>
+
 namespace Data {
 
+struct LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingConfigDetails {
+    QJsonArray folders;
+    QJsonArray devices;
+};
+
 struct LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingConfig {
     QString version;
     bool guiEnabled = false;
@@ -15,11 +23,12 @@ struct LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingConfig {
     QString guiUser;
     QString guiPasswordHash;
     QString guiApiKey;
+    std::optional<SyncthingConfigDetails> details;
 
     static QString locateConfigFile(const QString &fileName);
     static QString locateConfigFile();
     static QString locateHttpsCertificate();
-    bool restore(const QString &configFilePath);
+    bool restore(const QString &configFilePath, bool detailed = false);
     QString syncthingUrl() const;
 };
 
