@@ -3,7 +3,7 @@
 #include "./syncthingconnectionsettings.h"
 #include "./utils.h"
 
-#ifdef LIB_SYNCTHING_CONNECTOR_CONNECTION_MOCKED
+#if defined(LIB_SYNCTHING_CONNECTOR_CONNECTION_MOCKED) || defined(LIB_SYNCTHING_CONNECTOR_MOCKED)
 #include "./syncthingconnectionmockhelpers.h"
 #endif
 
@@ -114,6 +114,7 @@ SyncthingConnection::SyncthingConnection(
     , m_hasStatus(false)
     , m_hasEvents(false)
     , m_hasDiskEvents(false)
+    , m_statsRequested(false)
     , m_lastFileDeleted(false)
     , m_recordFileChanges(false)
     , m_useDeprecatedRoutes(true)
@@ -139,7 +140,7 @@ SyncthingConnection::SyncthingConnection(
     m_autoReconnectTimer.setInterval(SyncthingConnectionSettings::defaultReconnectInterval);
     QObject::connect(&m_autoReconnectTimer, &QTimer::timeout, this, &SyncthingConnection::autoReconnect);
 
-#ifdef LIB_SYNCTHING_CONNECTOR_CONNECTION_MOCKED
+#if defined(LIB_SYNCTHING_CONNECTOR_CONNECTION_MOCKED) || defined(LIB_SYNCTHING_CONNECTOR_MOCKED)
     setupTestData();
 #endif
 
@@ -190,6 +191,8 @@ QString SyncthingConnection::statusText(SyncthingStatus status)
         return tr("connected, synchronizing");
     case SyncthingStatus::RemoteNotInSync:
         return tr("connected, remote not in sync");
+    case SyncthingStatus::NoRemoteConnected:
+        return tr("connected, but all remote devices disconnected");
     default:
         return tr("unknown");
     }
@@ -201,35 +204,35 @@ QString SyncthingConnection::statusText(SyncthingStatus status)
 void SyncthingConnection::setLoggingFlags(SyncthingConnectionLoggingFlags flags)
 {
     m_loggingFlags = flags;
-    if (flags & SyncthingConnectionLoggingFlags::FromEnvironment) {
-        if (!(flags & SyncthingConnectionLoggingFlags::All) && qEnvironmentVariableIntValue(PROJECT_VARNAME_UPPER "_LOG_ALL")) {
+    if (flags && SyncthingConnectionLoggingFlags::FromEnvironment) {
+        if (!(flags && SyncthingConnectionLoggingFlags::All) && qEnvironmentVariableIntValue(PROJECT_VARNAME_UPPER "_LOG_ALL")) {
             m_loggingFlags |= SyncthingConnectionLoggingFlags::All;
         } else {
-            if (!(flags & SyncthingConnectionLoggingFlags::ApiCalls) && qEnvironmentVariableIntValue(PROJECT_VARNAME_UPPER "_LOG_API_CALLS")) {
+            if (!(flags && SyncthingConnectionLoggingFlags::ApiCalls) && qEnvironmentVariableIntValue(PROJECT_VARNAME_UPPER "_LOG_API_CALLS")) {
                 m_loggingFlags |= SyncthingConnectionLoggingFlags::ApiCalls;
             }
-            if (!(flags & SyncthingConnectionLoggingFlags::ApiCalls) && qEnvironmentVariableIntValue(PROJECT_VARNAME_UPPER "_LOG_API_REPLIES")) {
+            if (!(flags && SyncthingConnectionLoggingFlags::ApiCalls) && qEnvironmentVariableIntValue(PROJECT_VARNAME_UPPER "_LOG_API_REPLIES")) {
                 m_loggingFlags |= SyncthingConnectionLoggingFlags::ApiCalls;
             }
-            if (!(flags & SyncthingConnectionLoggingFlags::Events) && qEnvironmentVariableIntValue(PROJECT_VARNAME_UPPER "_LOG_EVENTS")) {
+            if (!(flags && SyncthingConnectionLoggingFlags::Events) && qEnvironmentVariableIntValue(PROJECT_VARNAME_UPPER "_LOG_EVENTS")) {
                 m_loggingFlags |= SyncthingConnectionLoggingFlags::Events;
             }
-            if (!(flags & SyncthingConnectionLoggingFlags::DirsOrDevsResetted)
+            if (!(flags && SyncthingConnectionLoggingFlags::DirsOrDevsResetted)
                 && qEnvironmentVariableIntValue(PROJECT_VARNAME_UPPER "_LOG_DIRS_OR_DEVS_RESETTED")) {
                 m_loggingFlags |= SyncthingConnectionLoggingFlags::Events;
             }
         }
     }
-    if ((m_loggingFlags & SyncthingConnectionLoggingFlags::DirsOrDevsResetted)
-        && !(m_loggingFlagsHandler & SyncthingConnectionLoggingFlags::DirsOrDevsResetted)) {
+    if ((m_loggingFlags && SyncthingConnectionLoggingFlags::DirsOrDevsResetted)
+        && !(m_loggingFlagsHandler && SyncthingConnectionLoggingFlags::DirsOrDevsResetted)) {
         QObject::connect(this, &SyncthingConnection::newDirs, [this](const auto &dirs) {
-            if (m_loggingFlags & SyncthingConnectionLoggingFlags::DirsOrDevsResetted) {
+            if (m_loggingFlags && SyncthingConnectionLoggingFlags::DirsOrDevsResetted) {
                 std::cerr << Phrases::Info << "Folder list renewed:" << Phrases::End;
                 std::cerr << displayNames(dirs).join(QStringLiteral(", ")).toStdString() << endl;
             }
         });
         QObject::connect(this, &SyncthingConnection::newDevices, [this](const auto &devs) {
-            if (m_loggingFlags & SyncthingConnectionLoggingFlags::DirsOrDevsResetted) {
+            if (m_loggingFlags && SyncthingConnectionLoggingFlags::DirsOrDevsResetted) {
                 std::cerr << Phrases::Info << "Device list renewed:" << Phrases::End;
                 std::cerr << displayNames(devs).join(QStringLiteral(", ")).toStdString() << endl;
             }
@@ -301,13 +304,16 @@ void SyncthingConnection::setPollingFlags(PollingFlags flags)
 
     // restart events/disk-events request as necessary
     if (normalEventsChanged) {
-        m_eventMask.clear();
+        if (!m_eventMask.isEmpty()) {
+            m_lastEventIdByMask.insert(m_eventMask, m_lastEventId);
+            m_eventMask.clear();
+        }
         cancelReplyWithoutAbortingConnection(m_eventsReply);
     }
     if (diskEventsChanged) {
         cancelReplyWithoutAbortingConnection(m_diskEventsReply);
     }
-    if (m_keepPolling) {
+    if (m_hasConfig && m_hasStatus && m_keepPolling) {
         requestEvents();
         requestDiskEvents(m_diskEventLimit);
     }
@@ -315,15 +321,15 @@ void SyncthingConnection::setPollingFlags(PollingFlags flags)
     // manage timers/requests for timer-based requests
     if (trafficStatsChanged) {
         manageTimerBasedRequest(m_trafficPollTimer, m_connectionsReply, *this, &SyncthingConnection::requestConnections,
-            m_keepPolling && (m_pollingFlags & PollingFlags::TrafficStatistics));
+            m_keepPolling && (m_pollingFlags && PollingFlags::TrafficStatistics));
     }
     if (devStatsChanged) {
         manageTimerBasedRequest(m_devStatsPollTimer, m_devStatsReply, *this, &SyncthingConnection::requestDeviceStatistics,
-            m_keepPolling && (m_pollingFlags & PollingFlags::DeviceStatistics));
+            m_keepPolling && (m_pollingFlags && PollingFlags::DeviceStatistics));
     }
     if (errorsChanged) {
         manageTimerBasedRequest(
-            m_errorsPollTimer, m_errorsReply, *this, &SyncthingConnection::requestErrors, m_keepPolling && (m_pollingFlags & PollingFlags::Errors));
+            m_errorsPollTimer, m_errorsReply, *this, &SyncthingConnection::requestErrors, m_keepPolling && (m_pollingFlags && PollingFlags::Errors));
     }
 }
 
@@ -444,7 +450,8 @@ void SyncthingConnection::connect()
     }
 
     // reset status
-    m_connectionAborted = m_abortingToConnect = m_abortingToReconnect = m_hasConfig = m_hasStatus = m_hasEvents = m_hasDiskEvents = false;
+    m_connectionAborted = m_abortingToConnect = m_abortingToReconnect = m_hasConfig = m_hasStatus = m_hasEvents = m_hasDiskEvents = m_statsRequested
+        = false;
 
     if (!checkConnectionConfiguration()) {
         return;
@@ -564,7 +571,7 @@ void SyncthingConnection::reconnect()
 
     // reset variables to track connection progress
     // note: especially resetting events is important as it influences the subsequent hasPendingRequests() call
-    m_hasConfig = m_hasStatus = m_hasEvents = m_hasDiskEvents = false;
+    m_hasConfig = m_hasStatus = m_hasEvents = m_hasDiskEvents = m_statsRequested = false;
 
     // reconnect right now if no pending requests to be aborted
     if (!hasPendingRequests()) {
@@ -613,6 +620,7 @@ void SyncthingConnection::continueReconnecting()
     m_abortingToConnect = m_abortingToReconnect = false;
     m_lastEventId = 0;
     m_lastDiskEventId = 0;
+    m_lastEventIdByMask.clear();
     m_configDir.clear();
     m_myId.clear();
     m_tilde.clear();
@@ -627,6 +635,7 @@ void SyncthingConnection::continueReconnecting()
     m_hasStatus = false;
     m_hasEvents = false;
     m_hasDiskEvents = false;
+    m_statsRequested = false;
     m_dirs.clear();
     m_devs.clear();
     m_errors.clear();
@@ -700,12 +709,15 @@ void SyncthingConnection::concludeConnection(StatusRecomputation flags)
     }
 
     // recompute status and emit events according to flags
-    if (!setStatus(SyncthingStatus::Idle) && (m_statusRecomputationFlags & StatusRecomputation::OutOfSyncDirs) && !m_hasOutOfSyncDirs.has_value()) {
+    if (!setStatus(SyncthingStatus::Idle) && (m_statusRecomputationFlags && StatusRecomputation::OutOfSyncDirs) && !m_hasOutOfSyncDirs.has_value()) {
         emit hasOutOfSyncDirsChanged();
     }
-    if (m_statusRecomputationFlags & StatusRecomputation::DirStats) {
+    if (m_statusRecomputationFlags && StatusRecomputation::DirStats) {
         emit dirStatisticsChanged();
     }
+    if (m_statusRecomputationFlags && StatusRecomputation::RemoteCompletion) {
+        emit devCompletionChanged();
+    }
 
     m_statusRecomputationFlags = StatusRecomputation::None;
 }
@@ -881,7 +893,7 @@ QString SyncthingConnection::deviceNameOrId(const QString &deviceId) const
 {
     for (const auto &dev : devInfo()) {
         if (dev.id == deviceId) {
-            return dev.name;
+            return dev.displayName();
         }
     }
     return deviceId;
@@ -952,13 +964,9 @@ void SyncthingConnection::continueConnecting()
     }
 
     // read additional information (beside config and status)
-    requestConnections();
-    requestDirStatistics();
-    requestDeviceStatistics();
     requestErrors();
     requestVersion();
     for (const SyncthingDir &dir : m_dirs) {
-        requestDirStatus(dir.id);
         if (!m_requestCompletion || dir.paused) {
             continue;
         }
@@ -1107,10 +1115,11 @@ bool SyncthingConnection::applySettings(SyncthingConnectionSettings &connectionS
  *
  * The precedence of the "connected" states from highest to lowest is:
  * 1. SyncthingStatus::Synchronizing
- * 2. SyncthingStatus::RemoteSynchronizing
+ * 2. SyncthingStatus::RemoteNotInSync
  * 3. SyncthingStatus::Scanning
  * 4. SyncthingStatus::Paused
- * 5. SyncthingStatus::Idle
+ * 5. SyncthingStatus::NoRemoteConnected
+ * 6. SyncthingStatus::Idle
  *
  * \remarks
  * - The "out-of-sync" status is (currently) *not* handled by this function. One needs to query this via
@@ -1149,19 +1158,18 @@ bool SyncthingConnection::setStatus(SyncthingStatus status)
         // check whether at least one directory is scanning, preparing to synchronize or synchronizing
         // note: We don't distinguish between "preparing to sync" and "synchronizing" for computing the overall
         //       status at the moment.
-        auto scanning = false, synchronizing = false, remoteSynchronizing = false;
-        if (m_statusComputionFlags & SyncthingStatusComputionFlags::Synchronizing
-            || m_statusComputionFlags & SyncthingStatusComputionFlags::Scanning) {
+        auto scanning = false, synchronizing = false, remoteSynchronizing = false, noRemoteConnected = true, devPaused = false;
+        if (m_statusComputionFlags && (SyncthingStatusComputionFlags::Synchronizing | SyncthingStatusComputionFlags::Scanning)) {
             for (const SyncthingDir &dir : m_dirs) {
                 switch (dir.status) {
                 case SyncthingDirStatus::WaitingToSync:
                 case SyncthingDirStatus::PreparingToSync:
                 case SyncthingDirStatus::Synchronizing:
-                    synchronizing = m_statusComputionFlags & SyncthingStatusComputionFlags::Synchronizing;
+                    synchronizing = m_statusComputionFlags && SyncthingStatusComputionFlags::Synchronizing;
                     break;
                 case SyncthingDirStatus::WaitingToScan:
                 case SyncthingDirStatus::Scanning:
-                    scanning = m_statusComputionFlags & SyncthingStatusComputionFlags::Scanning;
+                    scanning = m_statusComputionFlags && SyncthingStatusComputionFlags::Scanning;
                     break;
                 default:;
                 }
@@ -1171,30 +1179,39 @@ bool SyncthingConnection::setStatus(SyncthingStatus status)
             }
         }
 
-        // set the status to "remote synchronizing" if at least one remote device is still in progress
-        if (!synchronizing && (m_statusComputionFlags & SyncthingStatusComputionFlags::RemoteSynchronizing)) {
+        // check whether at least one device is synchronizing
+        // check whether at least one device is paused
+        // check whether at least one devices is connected
+        if (!synchronizing
+            && (m_statusComputionFlags
+                && (SyncthingStatusComputionFlags::RemoteSynchronizing | SyncthingStatusComputionFlags::NoRemoteConnected
+                    | SyncthingStatusComputionFlags::DevicePaused))) {
             for (const SyncthingDev &dev : m_devs) {
                 if (dev.status == SyncthingDevStatus::Synchronizing) {
                     remoteSynchronizing = true;
-                    break;
+                    if (m_statusComputionFlags && SyncthingStatusComputionFlags::RemoteSynchronizing) {
+                        break;
+                    }
+                }
+                if (dev.isConnected()) {
+                    noRemoteConnected = false;
+                }
+                if (dev.paused && dev.status != SyncthingDevStatus::ThisDevice) {
+                    devPaused = true;
                 }
             }
         }
 
         if (synchronizing) {
             status = SyncthingStatus::Synchronizing;
-        } else if (remoteSynchronizing) {
+        } else if ((m_statusComputionFlags && SyncthingStatusComputionFlags::RemoteSynchronizing) && remoteSynchronizing) {
             status = SyncthingStatus::RemoteNotInSync;
         } else if (scanning) {
             status = SyncthingStatus::Scanning;
-        } else if (m_statusComputionFlags & SyncthingStatusComputionFlags::DevicePaused) {
-            // check whether at least one device is paused
-            for (const SyncthingDev &dev : m_devs) {
-                if (dev.paused) {
-                    status = SyncthingStatus::Paused;
-                    break;
-                }
-            }
+        } else if ((m_statusComputionFlags && SyncthingStatusComputionFlags::DevicePaused) && devPaused) {
+            status = SyncthingStatus::Paused;
+        } else if ((m_statusComputionFlags && SyncthingStatusComputionFlags::NoRemoteConnected) && noRemoteConnected) {
+            status = SyncthingStatus::NoRemoteConnected;
         }
     }
     const auto hasStatusChanged = m_status != status || status == SyncthingStatus::Disconnected;
@@ -1211,7 +1228,7 @@ bool SyncthingConnection::setStatus(SyncthingStatus status)
  */
 void SyncthingConnection::emitError(const QString &message, const QJsonParseError &jsonError, QNetworkReply *reply, const QByteArray &response)
 {
-    if (loggingFlags() & SyncthingConnectionLoggingFlags::ApiReplies) {
+    if (loggingFlags() && SyncthingConnectionLoggingFlags::ApiReplies) {
         std::cerr << Phrases::Error << "JSON parsing error: " << message.toLocal8Bit().data() << jsonError.errorString().toLocal8Bit().data()
                   << " (at offset " << jsonError.offset << ')' << Phrases::End;
     }
@@ -1224,7 +1241,7 @@ void SyncthingConnection::emitError(const QString &message, const QJsonParseErro
  */
 void SyncthingConnection::emitError(const QString &message, SyncthingErrorCategory category, QNetworkReply *reply)
 {
-    if (loggingFlags() & SyncthingConnectionLoggingFlags::ApiReplies) {
+    if (loggingFlags() && SyncthingConnectionLoggingFlags::ApiReplies) {
         cerr << Phrases::Error << "Syncthing connection error: " << message.toLocal8Bit().data() << reply->errorString().toLocal8Bit().data() << endl;
     }
     emit error(message + reply->errorString(), category, reply->error(), reply->request(), reply->bytesAvailable() ? reply->readAll() : QByteArray());
@@ -1236,7 +1253,7 @@ void SyncthingConnection::emitError(const QString &message, SyncthingErrorCatego
  */
 void SyncthingConnection::emitError(const QString &message, QNetworkReply *reply)
 {
-    if (loggingFlags() & SyncthingConnectionLoggingFlags::ApiReplies) {
+    if (loggingFlags() && SyncthingConnectionLoggingFlags::ApiReplies) {
         cerr << Phrases::Error << "Syncthing API error: " << message.toLocal8Bit().data() << reply->errorString().toLocal8Bit().data() << endl;
     }
     emit error(message, SyncthingErrorCategory::SpecificRequest, reply->error(), reply->request(),
@@ -1290,7 +1307,7 @@ void SyncthingConnection::emitTildeChanged(const QString &newTilde, const QStrin
 void SyncthingConnection::handleFatalConnectionError()
 {
     // start the timer before emitting the event so its active state can be observed in event handler
-    if (m_autoReconnectTimer.interval() || !m_autoReconnectTimer.isActive()) {
+    if (m_autoReconnectTimer.interval() && !m_autoReconnectTimer.isActive()) {
         m_autoReconnectTimer.start();
     }
     setStatus(SyncthingStatus::Disconnected);
@@ -1356,6 +1373,21 @@ QUrl SyncthingConnection::makeUrlWithCredentials() const
     return url;
 }
 
+/*!
+ * \brief Computes the overall completion of all connected devices.
+ */
+SyncthingCompletion SyncthingConnection::computeOverallRemoteCompletion() const
+{
+    auto completion = SyncthingCompletion();
+    for (const auto &dev : m_devs) {
+        if (dev.isConnected()) {
+            completion += dev.overallCompletion;
+        }
+    }
+    completion.recomputePercentage();
+    return completion;
+}
+
 /*!
  * \fn SyncthingConnection::newConfig()
  * \brief Indicates new configuration (dirs, devs, ...) is available.
