@@ -91,9 +91,9 @@ struct LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingItem {
     /// \brief Whether the item is "checked"; not set by default but might be set to flag an item for some mass-action.
     Qt::CheckState checked = Qt::Unchecked;
     /// \brief Whether the item is present in the Syncthing database.
-    bool existsInDb = true;
+    std::optional<bool> existsInDb;
     /// \brief Whether the item is present in the local file system.
-    bool existsLocally = false;
+    std::optional<bool> existsLocally;
 
     bool isFilesystemItem() const;
 };
@@ -158,6 +158,8 @@ class LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingConnection : public QObject {
     Q_PROPERTY(quint64 totalOutgoingTraffic READ totalOutgoingTraffic NOTIFY trafficChanged)
     Q_PROPERTY(double totalIncomingRate READ totalIncomingRate NOTIFY trafficChanged)
     Q_PROPERTY(double totalOutgoingRate READ totalOutgoingRate NOTIFY trafficChanged)
+    Q_PROPERTY(Data::SyncthingOverallDirStatistics overallDirStatistics READ computeOverallDirStatistics NOTIFY dirStatisticsChanged)
+    Q_PROPERTY(Data::SyncthingCompletion overallRemoteCompletion READ computeOverallRemoteCompletion NOTIFY devCompletionChanged)
     Q_PROPERTY(QString lastSyncedFile READ lastSyncedFile)
     Q_PROPERTY(QString syncthingVersion READ syncthingVersion)
     Q_PROPERTY(CppUtilities::DateTime lastSyncTime READ lastSyncTime)
@@ -165,8 +167,8 @@ class LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingConnection : public QObject {
     Q_PROPERTY(QList<QSslError> expectedSslErrors READ expectedSslErrors)
 #endif
     Q_PROPERTY(std::vector<const SyncthingDev *> connectedDevices READ connectedDevices)
-    Q_PROPERTY(QStringList directoryIds READ directoryIds)
-    Q_PROPERTY(QStringList deviceIds READ deviceIds)
+    Q_PROPERTY(QStringList directoryIds READ directoryIds NOTIFY newDirs)
+    Q_PROPERTY(QStringList deviceIds READ deviceIds NOTIFY newDevices)
     Q_PROPERTY(QJsonObject rawConfig READ rawConfig NOTIFY newConfig)
     Q_PROPERTY(bool useDeprecatedRoutes READ isUsingDeprecatedRoutes WRITE setUseDeprecatedRoutes)
     Q_PROPERTY(bool pausingOnMeteredConnection READ isPausingOnMeteredConnection WRITE setPausingOnMeteredConnection)
@@ -275,6 +277,7 @@ public:
     const std::vector<SyncthingDev> &devInfo() const;
     const std::vector<SyncthingError> &errors() const;
     SyncthingOverallDirStatistics computeOverallDirStatistics() const;
+    SyncthingCompletion computeOverallRemoteCompletion() const;
     const QString &lastSyncedFile() const;
     CppUtilities::DateTime lastSyncTime() const;
     CppUtilities::DateTime startTime() const;
@@ -282,7 +285,7 @@ public:
     const QString &syncthingVersion() const;
     QStringList directoryIds() const;
     QStringList deviceIds() const;
-    QString deviceNameOrId(const QString &deviceId) const;
+    Q_INVOKABLE QString deviceNameOrId(const QString &deviceId) const;
     std::vector<const SyncthingDev *> connectedDevices() const;
     const QJsonObject &rawConfig() const;
     SyncthingDir *findDirInfo(const QString &dirId, int &row);
@@ -305,6 +308,7 @@ public Q_SLOTS:
 #endif
     bool applySettings(Data::SyncthingConnectionSettings &connectionSettings);
     void applyRawConfig();
+    void postRawConfig(const QByteArray &rawConfig);
 
     // methods to initiate/close connection
     void connect();
@@ -349,15 +353,19 @@ public Q_SLOTS:
     void requestLog();
     void requestOverride(const QString &dirId);
     void requestRevert(const QString &dirId);
-    void postConfigFromJsonObject(const QJsonObject &rawConfig);
-    void postConfigFromByteArray(const QByteArray &rawConfig);
 
 public:
     // methods to GET or POST information from/to Syncthing (non-slots)
+    QueryResult requestJsonData(const QByteArray &verb, const QString &path, const QUrlQuery &query, const QByteArray &data,
+        std::function<void(QJsonDocument &&, QString &&)> &&callback = std::function<void(QJsonDocument &&, QString &&)>(), bool rest = true,
+        bool longPolling = false);
     QueryResult browse(const QString &dirId, const QString &prefix, int level,
         std::function<void(std::vector<std::unique_ptr<SyncthingItem>> &&, QString &&)> &&callback);
     QueryResult ignores(const QString &dirId, std::function<void(SyncthingIgnores &&, QString &&)> &&callback);
     QueryResult setIgnores(const QString &dirId, const SyncthingIgnores &ignores, std::function<void(QString &&)> &&callback);
+    QueryResult postConfigFromJsonObject(
+        const QJsonObject &rawConfig, std::function<void(QString &&)> &&callback = std::function<void(QString &&)>());
+    QueryResult postConfigFromByteArray(const QByteArray &rawConfig, std::function<void(QString &&)> &&callback = std::function<void(QString &&)>());
 
 Q_SIGNALS:
     void syncthingUrlChanged(const QString &newUrl);
@@ -375,6 +383,7 @@ Q_SIGNALS:
     void fileChanged(const Data::SyncthingDir &dir, int index, const Data::SyncthingFileChange &fileChange);
     void downloadProgressChanged();
     void dirStatisticsChanged();
+    void devCompletionChanged();
     void dirCompleted(CppUtilities::DateTime when, const Data::SyncthingDir &dir, int index, const Data::SyncthingDev *remoteDev = nullptr);
     void newNotification(CppUtilities::DateTime when, const QString &message);
     void newDevAvailable(CppUtilities::DateTime when, const QString &devId, const QString &address);
@@ -434,7 +443,6 @@ private Q_SLOTS:
     void readRemoteFolderCompletion(const Data::SyncthingCompletion &completion, const QString &devId, Data::SyncthingDev *devInfo, int devIndex,
         const QString &dirId, Data::SyncthingDir *dirInfo, int dirIndex);
     void readRemoteIndexUpdated(SyncthingEventId eventId, const QJsonObject &eventData);
-    void readPostConfig();
     void readRescan();
     void readDevPauseResume();
     void readDirPauseResume();
@@ -477,9 +485,11 @@ private Q_SLOTS:
 
 private:
     // handler to evaluate results from request...() methods
+    void readJsonData(std::function<void(QJsonDocument &&, QString &&)> &&callback);
     void readBrowse(const QString &dirId, int levels, std::function<void(std::vector<std::unique_ptr<SyncthingItem>> &&, QString &&)> &&callback);
     void readIgnores(const QString &dirId, std::function<void(SyncthingIgnores &&, QString &&)> &&callback);
     void readSetIgnores(const QString &dirId, std::function<void(QString &&)> &&callback);
+    void readPostConfig(std::function<void(QString &&)> &&callback);
 
     // internal helper methods
     enum class StatusRecomputation {
@@ -487,6 +497,7 @@ private:
         Status = (1 << 0),
         OutOfSyncDirs = (1 << 1),
         DirStats = (1 << 2),
+        RemoteCompletion = (1 << 3),
         StatusAndOutOfSyncDirs = Status | OutOfSyncDirs
     };
     void concludeConnection(StatusRecomputation flags);
@@ -533,6 +544,7 @@ private:
     StatusRecomputation m_statusRecomputationFlags;
     SyncthingEventId m_lastEventId;
     SyncthingEventId m_lastDiskEventId;
+    QHash<QString, SyncthingEventId> m_lastEventIdByMask;
     QTimer m_trafficPollTimer;
     QTimer m_devStatsPollTimer;
     QTimer m_errorsPollTimer;
@@ -565,6 +577,7 @@ private:
     bool m_hasStatus;
     bool m_hasEvents;
     bool m_hasDiskEvents;
+    bool m_statsRequested;
     std::vector<SyncthingDir> m_dirs;
     std::vector<SyncthingDev> m_devs;
     std::vector<SyncthingError> m_errors;
@@ -750,7 +763,6 @@ inline bool SyncthingConnection::hasPendingRequests() const
 
 /*!
  * \brief Returns whether there are errors (notifications) available.
- * \remarks This flag is set to true when new notifications become available.
  */
 inline bool SyncthingConnection::hasErrors() const
 {
