@@ -85,17 +85,17 @@ void ModelTests::testDirectoryModel()
     QCOMPARE(model.index(1, 0).data(), QStringLiteral("Yet another folder"));
     QCOMPARE(model.index(2, 0).data(), QStringLiteral("A folder which is not shared"));
     const auto folder1Idx = model.index(0, 0);
-    QCOMPARE(model.rowCount(folder1Idx), 10);
+    QCOMPARE(model.rowCount(folder1Idx), 11);
     QCOMPARE(model.index(0, 0, folder1Idx).data(), QStringLiteral("ID"));
     QCOMPARE(model.index(0, 1, folder1Idx).data(), QStringLiteral("GXWxf-3zgnU"));
     QCOMPARE(model.index(1, 0, folder1Idx).data(), QStringLiteral("Path"));
     QCOMPARE(model.index(1, 1, folder1Idx).data(), QStringLiteral("this/path/is/not/supposed/to/exist"));
     const auto folder2Idx = model.index(1, 0);
-    QCOMPARE(model.rowCount(folder2Idx), 10);
+    QCOMPARE(model.rowCount(folder2Idx), 11);
     QCOMPARE(model.index(0, 1, folder2Idx).data(), QStringLiteral("zX8xfl3ygn-"));
     QCOMPARE(model.index(1, 1, folder2Idx).data(), QStringLiteral("..."));
     const auto folder3Idx = model.index(2, 0);
-    QCOMPARE(model.rowCount(folder2Idx), 10);
+    QCOMPARE(model.rowCount(folder2Idx), 11);
     QCOMPARE(model.index(0, 1, folder3Idx).data(), QStringLiteral("forever-alone"));
     QCOMPARE(model.index(1, 1, folder3Idx).data(), QStringLiteral("..."));
 }
@@ -109,17 +109,19 @@ void ModelTests::testDevicesModel()
     QCOMPARE(model.index(1, 0).data(), QStringLiteral("Other instance"));
     QCOMPARE(model.index(1, 1).data(), QStringLiteral("Unknown"));
     const auto dev1Idx = model.index(0, 0);
-    QCOMPARE(model.rowCount(dev1Idx), 5);
+    QCOMPARE(model.rowCount(dev1Idx), 6);
     QCOMPARE(model.index(0, 0, dev1Idx).data(), QStringLiteral("ID"));
     QCOMPARE(model.index(0, 1, dev1Idx).data(), QStringLiteral("P56IOI7-MZJNU2Y-IQGDREY-DM2MGTI-MGL3BXN-PQ6W5BM-TBBZ4TJ-XZWICQ2"));
-    QCOMPARE(model.index(1, 0, dev1Idx).data(), QStringLiteral("Address"));
-    QCOMPARE(model.index(1, 1, dev1Idx).data(), QStringLiteral("dynamic, tcp://192.168.1.2:22000"));
-    QCOMPARE(model.index(4, 0, dev1Idx).data(), QStringLiteral("Introducer"));
-    QCOMPARE(model.index(4, 1, dev1Idx).data(), QStringLiteral("no"));
+    QCOMPARE(model.index(1, 0, dev1Idx).data(), QStringLiteral("Out of Sync items"));
+    QCOMPARE(model.index(1, 1, dev1Idx).data(), QStringLiteral("none"));
+    QCOMPARE(model.index(2, 0, dev1Idx).data(), QStringLiteral("Address"));
+    QCOMPARE(model.index(2, 1, dev1Idx).data(), QStringLiteral("dynamic, tcp://192.168.1.2:22000"));
+    QCOMPARE(model.index(5, 0, dev1Idx).data(), QStringLiteral("Introducer"));
+    QCOMPARE(model.index(5, 1, dev1Idx).data(), QStringLiteral("no"));
     const auto dev2Idx = model.index(1, 0);
-    QCOMPARE(model.rowCount(dev2Idx), 5);
+    QCOMPARE(model.rowCount(dev2Idx), 6);
     QCOMPARE(model.index(0, 1, dev2Idx).data(), QStringLiteral("53STGR7-YBM6FCX-PAZ2RHM-YPY6OEJ-WYHVZO7-PCKQRCK-PZLTP7T"));
-    QCOMPARE(model.index(1, 1, dev2Idx).data(), QStringLiteral("dynamic, tcp://192.168.1.3:22000"));
+    QCOMPARE(model.index(2, 1, dev2Idx).data(), QStringLiteral("dynamic, tcp://192.168.1.3:22000"));
 }
 
 void ModelTests::testFileModel()
@@ -153,6 +155,7 @@ void ModelTests::testFileModel()
 
     QVERIFY(rootIdx.isValid());
     QCOMPARE(model.rowCount(rootIdx), 2);
+    QCOMPARE(rootIdx.sibling(rootIdx.row(), 4).data(Qt::ToolTipRole), QStringLiteral("Exists locally and globally"));
 
     // test access to nested folders
     const auto androidIdx = QPersistentModelIndex(model.index(0, 0, rootIdx));
@@ -170,16 +173,24 @@ void ModelTests::testFileModel()
     QCOMPARE(androidIdx.data(), QStringLiteral("100ANDRO"));
     QCOMPARE(cameraIdx.data(), QStringLiteral("Camera"));
     QCOMPARE(model.index(0, 0, cameraIdx).data(), QStringLiteral("IMG_20201114_124821.jpg"));
+    QVERIFY(model.index(0, 0, cameraIdx).data(Qt::DecorationRole).canConvert<QIcon>());
     QCOMPARE(model.index(0, 1, cameraIdx).data(), QStringLiteral("10.19 MiB"));
     QCOMPARE(model.index(0, 2, cameraIdx).data(), QStringLiteral("2020-12-16 22:31:34.500"));
+    QCOMPARE(model.index(0, 3, cameraIdx).data(), QVariant());
+    QVERIFY(model.index(0, 4, cameraIdx).data(Qt::DecorationRole).canConvert<QPixmap>());
+    QCOMPARE(model.index(0, 4, cameraIdx).data(Qt::ToolTipRole), QStringLiteral("Exists only globally"));
     QCOMPARE(model.index(1, 0, cameraIdx).data(), QStringLiteral("IMG_20201213_122451.jpg"));
     QCOMPARE(model.index(2, 0, cameraIdx).data(), QStringLiteral("IMG_20201213_122504.jpg"));
     QCOMPARE(model.index(3, 0, cameraIdx).data(), QStringLiteral("IMG_20201213_122505.jpg"));
     QCOMPARE(model.index(4, 0, cameraIdx).data(), QStringLiteral("IMG_20201213_125329.jpg"));
     QCOMPARE(model.index(5, 0, cameraIdx).data(), QVariant());
+    QCOMPARE(model.index(5, 0, cameraIdx).data(Qt::DecorationRole), QVariant());
     QCOMPARE(model.index(5, 1, cameraIdx).data(), QVariant());
     QCOMPARE(model.index(5, 2, cameraIdx).data(), QVariant());
     QCOMPARE(model.index(5, 3, cameraIdx).data(), QVariant());
+    QCOMPARE(model.index(5, 3, cameraIdx).data(), QVariant());
+    QCOMPARE(model.index(5, 4, cameraIdx).data(Qt::DecorationRole), QVariant());
+    QCOMPARE(model.index(5, 4, cameraIdx).data(Qt::ToolTipRole), QVariant());
 
     // test conversion of indexes to/from paths
     const auto testPath = QStringLiteral("Camera/IMG_20201213_122504.jpg");
@@ -238,12 +249,13 @@ void ModelTests::testFileModel()
 
     // selection actions when selection mode enabled
     actions = model.selectionActions();
-    QCOMPARE(actions.size(), 5);
-    QCOMPARE(actions.at(0)->text(), QStringLiteral("Discard selection and staged changes"));
-    QCOMPARE(actions.at(1)->text(), QStringLiteral("Ignore selected items (and their children)"));
-    QCOMPARE(actions.at(2)->text(), QStringLiteral("Include selected items (and their children)"));
-    QCOMPARE(actions.at(3)->text(), QStringLiteral("Ignore all items by default"));
-    QCOMPARE(actions.at(4)->text(), QStringLiteral("Remove ignore patterns matching against selected items (may affect other items as well)"));
+    QCOMPARE(actions.size(), 6);
+    QCOMPARE(actions.at(0)->text(), QStringLiteral("Uncheck all and discard staged changes"));
+    QCOMPARE(actions.at(1)->text(), QStringLiteral("Ignore checked items (and their children)"));
+    QCOMPARE(actions.at(2)->text(), QStringLiteral("Ignore and locally delete checked items (and their children)"));
+    QCOMPARE(actions.at(3)->text(), QStringLiteral("Include checked items (and their children)"));
+    QCOMPARE(actions.at(4)->text(), QStringLiteral("Ignore all items by default"));
+    QCOMPARE(actions.at(5)->text(), QStringLiteral("Remove ignore patterns matching checked items (may affect other items as well)"));
     actions.at(1)->trigger(); // this won't do much in the test setup
     actions.at(0)->trigger(); // disables selection mode
     qDeleteAll(actions);
@@ -297,21 +309,21 @@ void ModelTests::testFileModel()
 
     // test ignoring items by default
     actions = model.selectionActions();
-    QVERIFY(actions.size() > 3);
-    QCOMPARE(actions.at(3)->text(), QStringLiteral("Ignore all items by default"));
-    actions.at(3)->trigger();
+    QVERIFY(actions.size() > 4);
+    QCOMPARE(actions.at(4)->text(), QStringLiteral("Ignore all items by default"));
+    actions.at(4)->trigger();
     auto expectedDiff = QString(QChar('+') % model.m_ignoreAllByDefaultPattern % QChar('\n'));
     auto expectedPatterns = QStringList({ QStringLiteral("/**") });
     QCOMPARE(model.computeIgnorePatternDiff(), expectedDiff);
     QCOMPARE(model.computeNewIgnorePatterns().ignore, expectedPatterns);
 
     // test including items explicitly
-    QCOMPARE(actions.at(2)->text(), QStringLiteral("Include selected items (and their children)"));
+    QCOMPARE(actions.at(3)->text(), QStringLiteral("Include checked items (and their children)"));
     model.setData(androidIdx2, Qt::Checked, Qt::CheckStateRole);
     expectedDiff.prepend(QStringLiteral("+!/100ANDRO\n"));
     expectedPatterns.prepend(QStringLiteral("!/100ANDRO"));
     for (auto i = 0; i != 2; ++i) { // preform action twice; this should not lead to a duplicate
-        actions.at(2)->trigger();
+        actions.at(3)->trigger();
         QCOMPARE(model.computeIgnorePatternDiff(), expectedDiff);
         QCOMPARE(model.computeNewIgnorePatterns().ignore, expectedPatterns);
     }
@@ -319,7 +331,7 @@ void ModelTests::testFileModel()
     model.setData(cameraIdx2, Qt::Checked, Qt::CheckStateRole);
     expectedDiff.insert(QStringLiteral("+!/100ANDRO\n").size(), QStringLiteral("+!/Camera\n"));
     expectedPatterns.insert(1, QStringLiteral("!/Camera"));
-    actions.at(2)->trigger();
+    actions.at(3)->trigger();
     QCOMPARE(model.computeIgnorePatternDiff(), expectedDiff);
     QCOMPARE(model.computeNewIgnorePatterns().ignore, expectedPatterns);
     model.setData(cameraIdx2, Qt::Unchecked, Qt::CheckStateRole); // should the item be automatically unchecked?
@@ -327,7 +339,7 @@ void ModelTests::testFileModel()
     // test ignoring items explicitly
     model.setData(model.index(1, 0, cameraIdx2), Qt::Checked, Qt::CheckStateRole);
     model.setData(model.index(3, 0, cameraIdx2), Qt::Checked, Qt::CheckStateRole);
-    QCOMPARE(actions.at(1)->text(), QStringLiteral("Ignore selected items (and their children)"));
+    QCOMPARE(actions.at(1)->text(), QStringLiteral("Ignore checked items (and their children)"));
     actions.at(1)->trigger();
     expectedDiff.insert(
         QStringLiteral("+!/100ANDRO\n").size(), QStringLiteral("+/Camera/IMG_20201213_122451.jpg\n+/Camera/IMG_20201213_122505.jpg\n"));
@@ -340,9 +352,9 @@ void ModelTests::testFileModel()
     // note: Doing this makes not much sense after including items explicitly like the previous tests just did but this should of course work in general.
     qDeleteAll(actions);
     actions = model.selectionActions();
-    QVERIFY(actions.size() > 3);
-    QCOMPARE(actions.at(3)->text(), QStringLiteral("Include all items by default"));
-    actions.at(3)->trigger();
+    QVERIFY(actions.size() > 4);
+    QCOMPARE(actions.at(4)->text(), QStringLiteral("Include all items by default"));
+    actions.at(4)->trigger();
     expectedDiff.chop(model.m_ignoreAllByDefaultPattern.size() + 2);
     expectedPatterns.removeLast();
     QCOMPARE(model.computeIgnorePatternDiff(), expectedDiff);
@@ -351,13 +363,14 @@ void ModelTests::testFileModel()
     // test reviewing/applying changes
     qDeleteAll(actions);
     actions = model.selectionActions();
-    QVERIFY(actions.size() > 5);
-    QCOMPARE(actions.at(5)->text(), QStringLiteral("Review and apply staged changes"));
+    QVERIFY(actions.size() > 6);
+    QCOMPARE(actions.at(6)->text(), QStringLiteral("Review and apply staged changes"));
     connect(
         &model, &Data::SyncthingFileModel::actionNeedsConfirmation, this,
-        [&expectedDiff](QAction *action, const QString &message, const QString &diff = QString()) {
+        [&expectedDiff](QAction *action, const QString &message, const QString &diff, const QSet<QString> &localDeletions) {
             QCOMPARE(message, QStringLiteral("Do you want to apply the following changes?"));
             QCOMPARE(diff, expectedDiff);
+            QCOMPARE(localDeletions, QSet<QString>());
             action->trigger();
         },
         Qt::QueuedConnection);
@@ -379,7 +392,7 @@ void ModelTests::testFileModel()
             QVERIFY(message.startsWith(QStringLiteral("Unable to change ignore patterns:")));
         },
         Qt::QueuedConnection);
-    actions.at(5)->trigger();
+    actions.at(6)->trigger();
     m_timeout.start();
     m_loop.exec();
 
@@ -394,9 +407,9 @@ void ModelTests::testFileModel()
     model.m_isIgnoringAllByDefault = true;
     qDeleteAll(actions);
     actions = model.selectionActions();
-    QVERIFY(actions.size() > 4);
-    QCOMPARE(actions.at(3)->text(), QStringLiteral("Include all items by default"));
-    actions.at(3)->trigger();
+    QVERIFY(actions.size() > 5);
+    QCOMPARE(actions.at(4)->text(), QStringLiteral("Include all items by default"));
+    actions.at(4)->trigger();
     expectedDiff = QStringLiteral(" !/100ANDRO\n /Camera/IMG_20201213_122451.jpg\n /Camera/IMG_20201213_122505.jpg\n !/Camera\n-")
         % model.m_ignoreAllByDefaultPattern % QChar('\n');
     QCOMPARE(model.computeIgnorePatternDiff(), expectedDiff);
@@ -406,8 +419,8 @@ void ModelTests::testFileModel()
     model.resetMatchingIgnorePatterns();
     model.setCheckState(rootIdx, Qt::Unchecked, true);
     model.setCheckState(model.index(1, 0, cameraIdx2), Qt::Checked);
-    QCOMPARE(actions.at(4)->text(), QStringLiteral("Remove ignore patterns matching against selected items (may affect other items as well)"));
-    actions.at(4)->trigger();
+    QCOMPARE(actions.at(5)->text(), QStringLiteral("Remove ignore patterns matching checked items (may affect other items as well)"));
+    actions.at(5)->trigger();
     const auto indexInDiff = expectedDiff.indexOf(QStringLiteral(" /Camera/IMG_20201213_122451.jpg"));
     expectedDiff[indexInDiff] = QChar('-');
     expectedPatterns.removeAt(1);
@@ -420,7 +433,7 @@ void ModelTests::testFileModel()
     QCOMPARE(model.computeIgnorePatternDiff(), expectedDiff);
     QCOMPARE(model.computeNewIgnorePatterns().ignore, expectedPatterns);
     // remove the added-back pattern
-    actions.at(4)->trigger();
+    actions.at(5)->trigger();
     expectedDiff[indexInDiff] = QChar('-');
     expectedPatterns.removeAt(1);
     QCOMPARE(model.computeIgnorePatternDiff(), expectedDiff);
