@@ -4,42 +4,42 @@
 <context>
     <name>Data::StatusIconSettings</name>
     <message>
-        <location filename="../syncthingicons.cpp" line="232"/>
+        <location filename="../syncthingicons.cpp" line="239"/>
         <source>Misc. notifications</source>
         <translation>Benachrichtigungen</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="233"/>
+        <location filename="../syncthingicons.cpp" line="240"/>
         <source>Error</source>
         <translation>Fehler</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="234"/>
+        <location filename="../syncthingicons.cpp" line="241"/>
         <source>Warning</source>
         <translation>Warnungen</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="235"/>
+        <location filename="../syncthingicons.cpp" line="242"/>
         <source>Idle</source>
         <translation>Leerlauf</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="236"/>
+        <location filename="../syncthingicons.cpp" line="243"/>
         <source>Scanning</source>
         <translation>Scannen</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="237"/>
+        <location filename="../syncthingicons.cpp" line="244"/>
         <source>Synchronizing</source>
         <translation>Synchronisieren</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="238"/>
+        <location filename="../syncthingicons.cpp" line="245"/>
         <source>Paused</source>
         <translation>Pausiert</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="239"/>
+        <location filename="../syncthingicons.cpp" line="246"/>
         <source>Disconnected</source>
         <translation>Getrennt</translation>
     </message>
@@ -47,88 +47,102 @@
 <context>
     <name>Data::SyncthingDeviceModel</name>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="86"/>
-        <location filename="../syncthingdevicemodel.cpp" line="118"/>
+        <location filename="../syncthingdevicemodel.cpp" line="95"/>
+        <location filename="../syncthingdevicemodel.cpp" line="131"/>
         <source>ID</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="88"/>
+        <location filename="../syncthingdevicemodel.cpp" line="97"/>
         <source>Status</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="120"/>
+        <location filename="../syncthingdevicemodel.cpp" line="133"/>
+        <source>Out of Sync items</source>
+        <translation>Nicht synchronisiert Elemente</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdevicemodel.cpp" line="139"/>
         <source>Address</source>
         <translation>Adresse</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="122"/>
+        <location filename="../syncthingdevicemodel.cpp" line="141"/>
         <source>Connection type</source>
         <translation>Verbindungstyp</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="124"/>
+        <location filename="../syncthingdevicemodel.cpp" line="143"/>
         <source>Last seen</source>
         <translation>Zuletzt gesehen</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="126"/>
+        <location filename="../syncthingdevicemodel.cpp" line="145"/>
         <source>Compression</source>
         <translation>Kompression</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="128"/>
+        <location filename="../syncthingdevicemodel.cpp" line="147"/>
         <source>Certificate</source>
         <translation>Zertifikat</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="130"/>
+        <location filename="../syncthingdevicemodel.cpp" line="149"/>
         <source>Introducer</source>
         <translation>Verteilergerät</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="132"/>
+        <location filename="../syncthingdevicemodel.cpp" line="135"/>
         <source>Incoming traffic</source>
         <translation>Eingehender Datenverkehr</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="134"/>
+        <location filename="../syncthingdevicemodel.cpp" line="137"/>
         <source>Outgoing traffic</source>
         <translation>Ausgehender Datenverkehr</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="136"/>
+        <location filename="../syncthingdevicemodel.cpp" line="151"/>
         <source>Version</source>
         <translation></translation>
     </message>
+    <message numerus="yes">
+        <location filename="../syncthingdevicemodel.cpp" line="166"/>
+        <source>%1 item(s), ~ %2</source>
+        <translation>
+            <numerusform>%1 Element, ~ %2</numerusform>
+            <numerusform>%1 Elemente, ~ %2</numerusform>
+        </translation>
+    </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="157"/>
+        <location filename="../syncthingdevicemodel.cpp" line="183"/>
         <source>local</source>
         <translation>lokal</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="157"/>
+        <location filename="../syncthingdevicemodel.cpp" line="183"/>
         <source>remote</source>
         <translation>entfernt</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="162"/>
+        <location filename="../syncthingdevicemodel.cpp" line="188"/>
         <source>unknown or this device</source>
         <translation>unbekannt oder eigenes Gerät</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="167"/>
+        <location filename="../syncthingdevicemodel.cpp" line="164"/>
+        <location filename="../syncthingdevicemodel.cpp" line="193"/>
         <source>none</source>
-        <translation>keines</translation>
+        <translation>keine</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="169"/>
+        <location filename="../syncthingdevicemodel.cpp" line="195"/>
         <source>yes</source>
         <translation>ja</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="169"/>
+        <location filename="../syncthingdevicemodel.cpp" line="195"/>
         <source>no</source>
         <translation>nein</translation>
     </message>
@@ -196,56 +210,93 @@
 <context>
     <name>Data::SyncthingDirectoryModel</name>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="92"/>
-        <location filename="../syncthingdirectorymodel.cpp" line="124"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="96"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="128"/>
         <source>ID</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="94"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="98"/>
         <source>Status</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="126"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="130"/>
         <source>Path</source>
         <translation>Pfad</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="136"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="140"/>
         <source>Rescan interval</source>
         <translation>Scanintervall</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="138"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="142"/>
         <source>Last scan</source>
         <translation>Letzter Scan</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="140"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="144"/>
         <source>Last file</source>
         <translation>Letzte Datei</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="142"/>
-        <source>Errors</source>
-        <translation>Fehler</translation>
+        <location filename="../syncthingdirectorymodel.cpp" line="146"/>
+        <source>Out of Sync items</source>
+        <translation>Nicht synchronisiert Elemente</translation>
+    </message>
+    <message numerus="yes">
+        <location filename="../syncthingdirectorymodel.cpp" line="186"/>
+        <source>%1 item(s), ~ %2</source>
+        <translation>
+            <numerusform>%1 Element, ~ %2</numerusform>
+            <numerusform>%1 Elemente, ~ %2</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <location filename="../syncthingdirectorymodel.cpp" line="197"/>
+        <source>%1 item(s)</source>
+        <translation>
+            <numerusform>%1 Element</numerusform>
+            <numerusform>%1 Elemente</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <location filename="../syncthingdirectorymodel.cpp" line="199"/>
+        <source>%1 and %2 item(s)</source>
+        <translation>
+            <numerusform>%1 und %2 Element</numerusform>
+            <numerusform>%1 und %2 Elemente</numerusform>
+        </translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="165"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="394"/>
+        <source>Override remote changes</source>
+        <translation>Änderungen auf anderen Geräten überschreiben</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdirectorymodel.cpp" line="397"/>
+        <source>Revert local changes</source>
+        <translation>Lokale Änderungen zurücksetzen</translation>
+    </message>
+    <message>
+        <source>Errors</source>
+        <translation type="vanished">Fehler</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdirectorymodel.cpp" line="171"/>
         <source>not shared</source>
         <translation>nicht geteilt</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="172"/>
-        <location filename="../syncthingdirectorymodel.cpp" line="175"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="178"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="181"/>
         <source>unknown</source>
         <translation>unbekannt</translation>
     </message>
     <message numerus="yes">
-        <location filename="../syncthingdirectorymodel.cpp" line="186"/>
         <source>%1 and %2 item(s) out of sync</source>
-        <translation>
+        <translation type="vanished">
             <numerusform>&quot;%1&quot; und %2 Element nicht synchronisiert</numerusform>
             <numerusform>&quot;%1&quot; und %2 Elemente nicht synchronisiert</numerusform>
         </translation>
@@ -279,35 +330,36 @@
         <translation type="vanished">Nicht synchronisiert</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="178"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="184"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="191"/>
         <source>none</source>
         <translation>keine</translation>
     </message>
     <message numerus="yes">
-        <location filename="../syncthingdirectorymodel.cpp" line="184"/>
         <source>%1 item(s) out of sync</source>
-        <translation>
+        <translation type="vanished">
             <numerusform>%1 Element nicht synchronisiert</numerusform>
             <numerusform>%1 Elemente nicht synchronisiert</numerusform>
         </translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="260"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="278"/>
         <source>Deleted at %1</source>
         <translation>Gelöscht am %1</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="263"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="281"/>
         <source>Updated at %1</source>
         <translation>Aktualisiert am %1</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="276"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="294"/>
         <source>Click for details</source>
         <translation>Für details klicken</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="275"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="148"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="293"/>
         <source>Failed items</source>
         <translation>Fehlgeschlagene Elemente</translation>
     </message>
@@ -324,22 +376,22 @@
         <translation type="vanished">Nicht geteilt</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="128"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="132"/>
         <source>Global status</source>
         <translation>Globaler status</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="130"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="134"/>
         <source>Local status</source>
         <translation>Lokaler status</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="132"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="136"/>
         <source>Shared with</source>
         <translation>Geteilt mit</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="134"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="138"/>
         <source>Type</source>
         <translation>Typ</translation>
     </message>
@@ -403,12 +455,12 @@
 <context>
     <name>Data::SyncthingDownloadModel</name>
     <message>
-        <location filename="../syncthingdownloadmodel.cpp" line="96"/>
+        <location filename="../syncthingdownloadmodel.cpp" line="95"/>
         <source>Dir/item</source>
         <translation>Ordner/Element</translation>
     </message>
     <message>
-        <location filename="../syncthingdownloadmodel.cpp" line="98"/>
+        <location filename="../syncthingdownloadmodel.cpp" line="97"/>
         <source>Progress</source>
         <translation>Fortschritt</translation>
     </message>
@@ -429,159 +481,212 @@
 <context>
     <name>Data::SyncthingFileModel</name>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="291"/>
+        <location filename="../syncthingfilemodel.cpp" line="315"/>
         <source>Name</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="293"/>
+        <location filename="../syncthingfilemodel.cpp" line="317"/>
         <source>Size</source>
         <translation>Größe</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="295"/>
+        <location filename="../syncthingfilemodel.cpp" line="319"/>
         <source>Last modified</source>
         <translation>Zuletzt geändert</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="297"/>
+        <location filename="../syncthingfilemodel.cpp" line="321"/>
         <source>Ignore pattern</source>
         <translation>Ignoriermuster</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="345"/>
+        <location filename="../syncthingfilemodel.cpp" line="369"/>
         <source>%1 elements</source>
         <translation>%1 Elemente</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="226"/>
+        <location filename="../syncthingfilemodel.cpp" line="232"/>
         <source>Exists locally and globally</source>
         <translation>Existiert lokal und global</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="228"/>
+        <location filename="../syncthingfilemodel.cpp" line="234"/>
         <source>Exists only globally</source>
         <translation>Existiert nur global</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="230"/>
+        <location filename="../syncthingfilemodel.cpp" line="236"/>
         <source>Exists only locally</source>
         <translation>Existiert nur lokal</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="232"/>
+        <location filename="../syncthingfilemodel.cpp" line="238"/>
+        <source>Exists globally and perhaps locally</source>
+        <translation>Existiert global und vielleicht lokal</translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="240"/>
+        <source>Exists locally and perhaps globally</source>
+        <translation>Existiert lokal und vielleicht global</translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="242"/>
         <source>Does not exist</source>
         <translation>Existiert nicht</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="462"/>
+        <location filename="../syncthingfilemodel.cpp" line="486"/>
         <source>Refresh</source>
         <translation>Aktualisieren</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="465"/>
+        <location filename="../syncthingfilemodel.cpp" line="489"/>
         <source>Deselect recursively</source>
         <translation>Abwählen (rekursiv)</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="465"/>
+        <location filename="../syncthingfilemodel.cpp" line="489"/>
         <source>Select recursively</source>
         <translation>Auswählen (rekursiv)</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="467"/>
+        <location filename="../syncthingfilemodel.cpp" line="491"/>
         <source>Deselect single item</source>
         <translation>Abwählen (einzelnes Element)</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="467"/>
+        <location filename="../syncthingfilemodel.cpp" line="491"/>
         <source>Select single item</source>
         <translation>Auswählen (einzelnes Element)</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="469"/>
+        <location filename="../syncthingfilemodel.cpp" line="493"/>
         <source>Open local version</source>
         <translation>Lokale Version öffnen</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="469"/>
+        <location filename="../syncthingfilemodel.cpp" line="493"/>
         <source>Copy local path</source>
         <translation>Lokalen Pfad kopieren</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="469"/>
+        <location filename="../syncthingfilemodel.cpp" line="493"/>
         <source>Browse locally</source>
         <translation>Im lokalen Dateibrowser öffnen</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="746"/>
+        <location filename="../syncthingfilemodel.cpp" line="778"/>
         <source>Select items to sync/ignore</source>
         <translation>Elemente zum Synchronisieren/Ignorieren auswählen</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="752"/>
+        <location filename="../syncthingfilemodel.cpp" line="780"/>
+        <source>Select</source>
+        <translation>Auswahl</translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="785"/>
         <source>Discard staged changes</source>
         <translation>Vorgemerkte Änderungen verwerfen</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="762"/>
-        <source>Discard selection and staged changes</source>
+        <location filename="../syncthingfilemodel.cpp" line="795"/>
+        <source>Uncheck all and discard staged changes</source>
         <translation>Vorgemerkte Änderungen und Auswahl verwerfen</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="775"/>
+        <location filename="../syncthingfilemodel.cpp" line="797"/>
+        <source>Discard</source>
+        <translation>Verwerfen</translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="809"/>
+        <source>Ignore checked items (and their children)</source>
+        <translation>Ausgewählte Elemente ignorieren (einschließlich untergeordneter Elemente)</translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="816"/>
+        <source>Ignore and locally delete checked items (and their children)</source>
+        <translation>Ausgewählte Elemente ignorieren und lokal löschen (einschließlich untergeordneter Elemente)</translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="823"/>
+        <source>Include checked items (and their children)</source>
+        <translation>Ausgewählte Elemente synchronisieren (einschließlich untergeordneter Elemente)</translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="862"/>
+        <source>Remove ignore patterns matching checked items (may affect other items as well)</source>
+        <translation>Lösche Ignoriermuster die mit ausgewählten Elementen übereinstimmen (kann auch andere Elemente betreffen)</translation>
+    </message>
+    <message>
+        <source>Discard selection and staged changes</source>
+        <translation type="vanished">Vorgemerkte Änderungen und Auswahl verwerfen</translation>
+    </message>
+    <message>
         <source>Ignore selected items (and their children)</source>
-        <translation>Ausgewählte Elemente ignorieren (und untergeordnete Elemente)</translation>
+        <translation type="vanished">Ausgewählte Elemente ignorieren (und untergeordnete Elemente)</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="780"/>
         <source>Include selected items (and their children)</source>
-        <translation>Ausgewählte Elemente synchronisieren (und untergeordnete Elemente)</translation>
+        <translation type="vanished">Ausgewählte Elemente synchronisieren (und untergeordnete Elemente)</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="787"/>
+        <location filename="../syncthingfilemodel.cpp" line="831"/>
         <source>Include all items by default</source>
         <translation>Alle Elemente standardmäßig synchronisieren</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="787"/>
+        <location filename="../syncthingfilemodel.cpp" line="831"/>
         <source>Ignore all items by default</source>
         <translation>Alle Elemente standardmäßig ignorieren</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="817"/>
         <source>Remove ignore patterns matching against selected items (may affect other items as well)</source>
-        <translation>Lösche Ignoriermuster die mit ausgewählten Elementen übereinstimmen (kann auch andere Elemente betreffen)</translation>
+        <translation type="vanished">Lösche Ignoriermuster die mit ausgewählten Elementen übereinstimmen (kann auch andere Elemente betreffen)</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="845"/>
+        <location filename="../syncthingfilemodel.cpp" line="890"/>
         <source>Review and apply staged changes</source>
         <translation>Vorgemerkte Änderungen überprüfen und anwenden</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="852"/>
+        <location filename="../syncthingfilemodel.cpp" line="892"/>
+        <source>Apply</source>
+        <translation>Anwenden</translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="900"/>
         <source>Do you want to apply the following changes?</source>
         <translation>Sollen die folgenden Änderungen angewandt werden?</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="860"/>
+        <location filename="../syncthingfilemodel.cpp" line="908"/>
         <source>Cannot apply ignore patterns while a previous request for ignore patterns is still pending.</source>
         <translation>Ignoriermuster können nicht gespeichert werden, da noch eine vorherige Abfrage in Gange ist.</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="868"/>
+        <location filename="../syncthingfilemodel.cpp" line="916"/>
         <source>Unable to change ignore patterns:
 %1</source>
         <translation>Kann Ignoriermuster nicht speichern:
 %1</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="882"/>
+        <location filename="../syncthingfilemodel.cpp" line="982"/>
         <source>Ignore patterns have been changed.</source>
         <translation>Ignoriermuster wurden gespeichert.</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="1057"/>
+        <location filename="../syncthingfilemodel.cpp" line="985"/>
+        <source>Ignore patterns have been changed but the following local files could not be deleted:
+</source>
+        <translation>Ignoriermuster wurden gespeichert, aber die folgenden lokalen Dateien konnten nicht gelöscht werden:
+</translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="1155"/>
         <source>Cannot query ignore patterns while a previous request for ignore patterns is still pending.</source>
         <translation>Ignoriermuster können nicht abgefragt werden, da noch eine vorherige Abfrage in Gange ist.</translation>
     </message>
@@ -622,32 +727,37 @@
 <context>
     <name>Data::SyncthingStatusComputionModel</name>
     <message>
-        <location filename="../syncthingstatuscomputionmodel.cpp" line="37"/>
+        <location filename="../syncthingstatuscomputionmodel.cpp" line="38"/>
         <source>Local dir is scanning</source>
         <translation>Lokaler Ordner wird gescannt</translation>
     </message>
     <message>
-        <location filename="../syncthingstatuscomputionmodel.cpp" line="39"/>
+        <location filename="../syncthingstatuscomputionmodel.cpp" line="40"/>
         <source>Local dir is synchronizing</source>
         <translation>Lokaler Ordner wird synchronisiert</translation>
     </message>
     <message>
-        <location filename="../syncthingstatuscomputionmodel.cpp" line="41"/>
+        <location filename="../syncthingstatuscomputionmodel.cpp" line="42"/>
         <source>Remote dir has outstanding progress</source>
         <translation>Entfernter Ordner hat ausstehende Elemente</translation>
     </message>
     <message>
-        <location filename="../syncthingstatuscomputionmodel.cpp" line="43"/>
+        <location filename="../syncthingstatuscomputionmodel.cpp" line="44"/>
+        <source>No remote device connected</source>
+        <translation>Nicht mit anderen Geräten verbunden</translation>
+    </message>
+    <message>
+        <location filename="../syncthingstatuscomputionmodel.cpp" line="46"/>
         <source>A device is paused</source>
         <translation>Ein Gerät ist pausiert</translation>
     </message>
     <message>
-        <location filename="../syncthingstatuscomputionmodel.cpp" line="45"/>
+        <location filename="../syncthingstatuscomputionmodel.cpp" line="48"/>
         <source>Local dir is out of sync</source>
         <translation>Lokaler Ordner ist nicht synchronisiert</translation>
     </message>
     <message>
-        <location filename="../syncthingstatuscomputionmodel.cpp" line="47"/>
+        <location filename="../syncthingstatuscomputionmodel.cpp" line="50"/>
         <source>Unread notification present</source>
         <translation>Ungelesene Benachrichtigungen</translation>
     </message>
