@@ -3,6 +3,10 @@
 
 #include "../global.h"
 
+#include <QtGlobal>
+
+QT_FORWARD_DECLARE_CLASS(QString)
+
 namespace Data {
 class SyncthingConnection;
 }
@@ -10,6 +14,7 @@ class SyncthingConnection;
 namespace QtGui {
 
 SYNCTHINGWIDGETS_EXPORT void handleRelevantControlsChanged(bool visible, int tabIndex, Data::SyncthingConnection &connection);
+SYNCTHINGWIDGETS_EXPORT QString readmeUrl();
 
 } // namespace QtGui
 
