@@ -5,6 +5,7 @@
 #include "../misc/otherdialogs.h"
 #include "../misc/statusinfo.h"
 #include "../misc/syncthinglauncher.h"
+#include "../misc/utils.h"
 
 // use meta-data of syncthingtray application here
 #include "resources/../../tray/resources/config.h"
@@ -35,7 +36,6 @@
 #include <QVBoxLayout>
 
 #include <initializer_list>
-#include <string_view>
 
 #if !defined(SYNCTHINGWIDGETS_AUTOSTART_DISABLED)                                                                                                    \
     && ((defined(PLATFORM_LINUX) && !defined(Q_OS_ANDROID)) || defined(PLATFORM_WINDOWS) || defined(PLATFORM_MAC))
@@ -189,7 +189,7 @@ bool Wizard::changeSettings()
             = (mainConfig() == MainConfiguration::LauncherExternal || mainConfig() == MainConfiguration::LauncherBuiltIn);
     }
 #ifdef LIB_SYNCTHING_CONNECTOR_SUPPORT_SYSTEMD
-    settings.systemd.considerForReconnect = settings.systemd.showButton = extraConfig() & ExtraConfiguration::SystemdIntegration;
+    settings.systemd.considerForReconnect = settings.systemd.showButton = extraConfig() && ExtraConfiguration::SystemdIntegration;
 #endif
 
     // enable/disable auto start
@@ -277,7 +277,7 @@ void Wizard::showDetailsFromSetupDetection()
     if (detection.connection.isConnected()) {
         auto statusInfo = StatusInfo();
         statusInfo.updateConnectionStatus(detection.connection);
-        statusInfo.updateConnectionStatus(detection.connection);
+        statusInfo.updateConnectedDevices(detection.connection);
         infoItems << tr("Could connect to Syncthing under: ") + detection.connection.syncthingUrl();
         infoItems << tr("Syncthing version: ") + detection.connection.syncthingVersion();
         infoItems << tr("Syncthing device ID: ") + detection.connection.myId();
@@ -443,13 +443,7 @@ void Wizard::handleConfigurationApplied(const QString &configError, Data::Syncth
 WelcomeWizardPage::WelcomeWizardPage(QWidget *parent)
     : QWizardPage(parent)
 {
-    auto readmeUrl = QString();
-    if constexpr (std::string_view(APP_VERSION).find('-') == std::string_view::npos) {
-        readmeUrl = QStringLiteral("https://github.com/" APP_AUTHOR "/" PROJECT_NAME "/blob/v" APP_VERSION "/README.md");
-    } else {
-        readmeUrl = QStringLiteral("https://github.com/" APP_AUTHOR "/" PROJECT_NAME "/blob/master/README.md");
-    }
-
+    const auto readmeUrl = QtGui::readmeUrl();
     auto *const infoLabel = new QLabel(this);
     auto infoText = QString();
     const auto &settings = Settings::values();
@@ -767,7 +761,7 @@ void MainConfigWizardPage::initializePage()
         } else {
             m_ui->invalidConfigLabel->setText(tr("<b>The Syncthing config could be located under \"%1\" but it seems invalid/incomplete.</b> Hence "
                                                  "Syncthing is assumed to be not running.")
-                                                  .arg(detection.configFilePath));
+                    .arg(detection.configFilePath));
             m_ui->invalidConfigLabel->show();
         }
     }
@@ -1005,7 +999,7 @@ void ApplyWizardPage::initializePage()
     }
     addListItem(mainConfig);
 #ifdef LIB_SYNCTHING_CONNECTOR_SUPPORT_SYSTEMD
-    logFeature(tr("systemd integration"), wizard->extraConfig() & ExtraConfiguration::SystemdIntegration,
+    logFeature(tr("systemd integration"), wizard->extraConfig() && ExtraConfiguration::SystemdIntegration,
         currentSettings.systemd.showButton && currentSettings.systemd.considerForReconnect);
 #endif
 #ifdef SETTINGS_WIZARD_AUTOSTART
@@ -1025,8 +1019,8 @@ void ApplyWizardPage::initializePage()
     }
 #endif
     html.append(QStringLiteral("</ul><p><b>%1</b></p><ul><li>%2</li><li>%3</li><li>%4</li></ul>")
-                    .arg(tr("Further information:"), tr("Click on \"Show details from setup detection\" for further details."),
-                        tr("If you want to do amendments, you can head back one or more steps."), tr("If you abort now, nothing will be changed.")));
+            .arg(tr("Further information:"), tr("Click on \"Show details from setup detection\" for further details."),
+                tr("If you want to do amendments, you can head back one or more steps."), tr("If you abort now, nothing will be changed.")));
     m_ui->summaryTextBrowser->setHtml(html);
 }
 
@@ -1111,8 +1105,7 @@ void FinalWizardPage::showResults()
         }
     } else {
         setSubTitle(tr("Not all changes could be applied"));
-        m_label->setText(
-            QStringLiteral("<p>%1</p><p>%2</p>")
+        m_label->setText(QStringLiteral("<p>%1</p><p>%2</p>")
                 .arg(wizard->configError(),
                     tr("You may try to head back one or more steps and try again or finish the wizard and configure Syncthing Tray manually.")));
     }
