@@ -2,17 +2,21 @@
 #define QT_UTILITIES_GUI_QTQUICK
 #endif
 
+#ifdef GUI_QTWIDGETS
 #include "./singleinstance.h"
 
 #include "../gui/trayicon.h"
 #include "../gui/traywidget.h"
+#endif
 
 #ifdef GUI_QTQUICK
-#include "../gui/app.h"
+#include "../gui/quick/app.h"
 #endif
 
 #include <syncthingwidgets/misc/syncthinglauncher.h>
+#ifdef GUI_QTWIDGETS
 #include <syncthingwidgets/settings/settings.h>
+#endif
 
 #include <syncthingmodel/syncthingicons.h>
 
@@ -39,13 +43,13 @@
 #include <qtutilities/resources/resources.h>
 #include <qtutilities/settingsdialog/qtsettings.h>
 
-#include <QMessageBox>
 #include <QNetworkAccessManager>
 #include <QSettings>
 #include <QStringBuilder>
 
 #ifdef GUI_QTWIDGETS
 #include <QApplication>
+#include <QMessageBox>
 using QtApp = QApplication;
 #else
 #include <QGuiApplication>
@@ -57,9 +61,11 @@ using QtApp = QGuiApplication;
 #include <QtWebView/QtWebView>
 #endif
 
+#ifdef SYNCTHINGTRAY_HAS_WEBVIEW_PAGE
 #include <QQmlEngineExtensionPlugin>
 Q_IMPORT_QML_PLUGIN(WebViewItemPlugin)
 #endif
+#endif
 
 #include <iostream>
 
@@ -81,6 +87,8 @@ Q_IMPORT_PLUGIN(ForkAwesomeIconEnginePlugin)
 
 ENABLE_QT_RESOURCES_OF_STATIC_DEPENDENCIES
 
+#ifdef GUI_QTWIDGETS
+
 #ifdef LIB_SYNCTHING_CONNECTOR_SUPPORT_SYSTEMD
 static void handleSystemdServiceError(const QString &context, const QString &name, const QString &message)
 {
@@ -182,11 +190,16 @@ static void shutdownSyncthingTray()
     Settings::Launcher::terminate();
 }
 
+#endif
+
 static int runApplication(int argc, const char *const *argv)
 {
     // setup argument parser
     auto parser = ArgumentParser();
     auto qtConfigArgs = QT_CONFIG_ARGUMENTS();
+    auto insecureArg = ConfigValueArgument("insecure", '\0', "allow any self-signed certificate");
+    insecureArg.setFlags(Argument::Flags::Deprecated, true); // hide as it is only for development
+#ifdef GUI_QTWIDGETS
     auto windowedArg = ConfigValueArgument("windowed", 'w', "opens the tray menu as a regular window");
     auto showWebUiArg = ConfigValueArgument("webui", '\0', "instantly shows the web UI - meant for creating shortcut to web UI");
     auto triggerArg = ConfigValueArgument("trigger", '\0', "instantly shows the left-click tray menu - meant for creating a shortcut");
@@ -195,8 +208,6 @@ static int runApplication(int argc, const char *const *argv)
     assumeFirstLaunchArg.setFlags(Argument::Flags::Deprecated, true); // hide as it is debug-only
     auto wipArg = ConfigValueArgument("wip", '\0', "enables WIP features");
     wipArg.setFlags(Argument::Flags::Deprecated, true); // hide as it is debug-only
-    auto insecureArg = ConfigValueArgument("insecure", '\0', "allow any self-signed certificate");
-    insecureArg.setFlags(Argument::Flags::Deprecated, true); // hide as it is only for development
     auto waitForTrayArg = ConfigValueArgument("wait", '\0',
         "wait until the system tray becomes available instead of showing an error message if the system tray is not available on start-up");
     auto connectionArg = ConfigValueArgument("connection", '\0', "specifies one or more connection configurations to be used", { "config name" });
@@ -211,6 +222,7 @@ static int runApplication(int argc, const char *const *argv)
     auto &widgetsGuiArg = qtConfigArgs.qtWidgetsGuiArg();
     widgetsGuiArg.addSubArguments({ &windowedArg, &showWebUiArg, &triggerArg, &waitForTrayArg, &connectionArg, &configPathArg, &singleInstanceArg,
         &newInstanceArg, &replaceArg, &showWizardArg, &assumeFirstLaunchArg, &wipArg, &insecureArg });
+#endif
 #ifdef GUI_QTQUICK
     auto &quickGuiArg = qtConfigArgs.qtQuickGuiArg();
     quickGuiArg.addSubArgument(&insecureArg);
@@ -238,14 +250,21 @@ static int runApplication(int argc, const char *const *argv)
     syncthingArg.setSubArguments({ &syncthingHelp });
 #endif
 
-    parser.setMainArguments({ &widgetsGuiArg,
+    parser.setMainArguments({
+#ifdef GUI_QTWIDGETS
+        &widgetsGuiArg,
+#endif
 #ifdef GUI_QTQUICK
         &quickGuiArg,
 #endif
 #ifdef SYNCTHINGTRAY_USE_LIBSYNCTHING
         &cliArg, &syncthingArg,
 #endif
-        &parser.noColorArg(), &parser.helpArg(), &quitArg });
+        &parser.noColorArg(), &parser.helpArg(),
+#ifdef GUI_QTWIDGETS
+        &quitArg
+#endif
+    });
 
     // parse arguments
 #if defined(Q_OS_ANDROID)
@@ -257,6 +276,7 @@ static int runApplication(int argc, const char *const *argv)
 #endif
     parser.parseArgs(argc, argv);
 
+#ifdef GUI_QTWIDGETS
     // quit already running application if quit is present
     static auto firstRun = true;
     if (quitArg.isPresent() && !firstRun) {
@@ -264,9 +284,15 @@ static int runApplication(int argc, const char *const *argv)
         QCoreApplication::quit();
         return EXIT_SUCCESS;
     }
+#endif
 
 #ifdef GUI_QTQUICK
     if (quickGuiArg.isPresent()) {
+#ifdef SYNCTHINGTRAY_FORCE_VULKAN
+        // force Vulkan RHI backend to test it on Android or other platforms where setting an env variable is not so easy
+        qputenv("QSG_RHI_BACKEND", "vulkan");
+        qputenv("QSG_INFO", "1");
+#endif
 #ifdef SYNCTHINGTRAY_HAS_WEBVIEW
         QtWebView::initialize();
 #endif
@@ -280,16 +306,21 @@ static int runApplication(int argc, const char *const *argv)
 #endif
 #endif
         qtConfigArgs.applySettings(true);
-        qtConfigArgs.applySettingsForQuickGui();
         networkAccessManager().setParent(&app);
 
         auto quickApp = App(insecureArg.isPresent());
         quickApp.applySettings();
-        QObject::connect(&app, &QCoreApplication::aboutToQuit, &shutdownSyncthingTray);
-        return app.exec();
+        QObject::connect(&app, &QCoreApplication::aboutToQuit, &quickApp, &App::shutdown);
+        SyncthingLauncher::setMainInstance(quickApp.launcher());
+        const auto res = app.exec();
+#if defined(Q_OS_ANDROID)
+        qDebug() << "Qt event loop exited with return code " << res;
+#endif
+        return res;
     }
 #endif
 
+#ifdef GUI_QTWIDGETS
     // quit unless Qt Widgets GUI should be shown
     if (!widgetsGuiArg.isPresent()) {
         return EXIT_SUCCESS;
@@ -386,9 +417,22 @@ static int runApplication(int argc, const char *const *argv)
         trigger(triggerArg.isPresent(), showWebUiArg.isPresent(), showWizardArg.isPresent());
     }
     return res;
+#else
+    return EXIT_SUCCESS;
+#endif
 }
 
-int main(int argc, char *argv[])
+// define macro to export main function if required
+// note: This macro can be removed when depending on c++utilities 5.28.0.
+#ifndef CPP_UTILITIES_MAIN_EXPORT
+#ifdef PLATFORM_ANDROID
+#define CPP_UTILITIES_MAIN_EXPORT CPP_UTILITIES_GENERIC_LIB_EXPORT
+#else
+#define CPP_UTILITIES_MAIN_EXPORT
+#endif
+#endif
+
+CPP_UTILITIES_MAIN_EXPORT int main(int argc, char *argv[])
 {
     SET_APPLICATION_INFO;
     CMD_UTILS_CONVERT_ARGS_TO_UTF8;
