@@ -5,12 +5,15 @@
 #endif
 
 #include <QApplication>
+#include <QFontMetrics>
 #include <QMenu>
 #include <QMouseEvent>
 #include <QPainter>
+#include <QPalette>
 #include <QPoint>
 #include <QStyleHints>
 #include <QStyleOptionViewItem>
+#include <QTextOption>
 #include <QTreeView>
 
 namespace QtGui {
@@ -38,32 +41,6 @@ static inline QEvent::Type contextMenuEventType()
 #endif
 }
 
-/*!
- * \class UnifiedItemDelegate
- * \brief The UnifiedItemDelegate class draws view items without visual separation.
- *
- * This style sets the view item position to "OnlyOne" to prevent styles from drawing separations
- * too noisily between items. It is used to achieve a cleaner look of the directory/devices tree
- * view.
- *
- * \remarks
- * The main motivation for this is the Windows 11 style which otherwise draws vertical lines between
- * the columns which does not look nice at all in these tree views.
- */
-
-UnifiedItemDelegate::UnifiedItemDelegate(QObject *parent)
-    : QStyledItemDelegate(parent)
-{
-}
-
-void UnifiedItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
-{
-    auto opt = option;
-    initStyleOption(&opt, index);
-    opt.viewItemPosition = QStyleOptionViewItem::OnlyOne;
-    QStyledItemDelegate::paint(painter, opt, index);
-}
-
 BasicTreeView::BasicTreeView(QWidget *parent)
     : QTreeView(parent)
     , m_contextMenuEventType(contextMenuEventType())
@@ -142,4 +119,78 @@ void setupPainterToDrawViewItemText(QPainter *painter, QStyleOptionViewItem &opt
     painter->setPen(opt.palette.color(QPalette::HighlightedText));
 }
 
+void drawField(const QStyledItemDelegate *delegate, QPainter *painter, QStyleOptionViewItem &opt, const QModelIndex &index, int detailRole)
+{
+    // init style options to use drawControl(), except for the text
+    opt.text.clear();
+    opt.features = QStyleOptionViewItem::None;
+    drawBasicItemViewItem(*painter, opt);
+
+    const auto fieldName = delegate->displayText(index.data(Qt::DisplayRole), opt.locale);
+    const auto fieldValue = delegate->displayText(index.data(detailRole), opt.locale);
+
+    // draw icon
+    auto iconRect
+        = QRect(opt.rect.x() + listItemPadding, opt.rect.y() + centerObj(opt.rect.height(), listItemIconSize), listItemIconSize, listItemIconSize);
+    painter->drawPixmap(iconRect, index.data(Qt::DecorationRole).value<QIcon>().pixmap(listItemIconSize, listItemIconSize));
+
+    // compute rectangle for field name and value
+    auto textRect = QRectF(opt.rect);
+    textRect.setX(iconRect.right() + listItemSpacing);
+    textRect.setWidth(textRect.width() - listItemPadding);
+    auto textOption = QTextOption();
+    textOption.setWrapMode(QTextOption::NoWrap);
+    textOption.setAlignment(opt.displayAlignment);
+    auto fieldNameRect = painter->boundingRect(textRect, fieldName, textOption);
+
+    // draw field name
+    setupPainterToDrawViewItemText(painter, opt);
+    painter->drawText(textRect, fieldName, textOption);
+
+    // draw status text
+    textOption.setAlignment(Qt::AlignRight | Qt::AlignVCenter);
+    textRect.setX(textRect.x() + fieldNameRect.width() + listItemSpacing);
+    painter->drawText(textRect, painter->fontMetrics().elidedText(fieldValue, Qt::ElideRight, static_cast<int>(textRect.width())), textOption);
+}
+
+void drawIdAndStatus(const QStyledItemDelegate *delegate, QPainter *painter, QStyleOptionViewItem &opt, const QModelIndex &index,
+    int statusStringRole, int statusColorRole, int buttonWidth)
+{
+    const auto id = delegate->displayText(index.data(Qt::DisplayRole), opt.locale);
+    const auto statusText = delegate->displayText(index.data(statusStringRole), opt.locale);
+
+    // init style options to use drawControl(), except for the text
+    opt.text.clear();
+    opt.features = QStyleOptionViewItem::None;
+    drawBasicItemViewItem(*painter, opt);
+
+    // draw icon
+    auto iconRect
+        = QRect(opt.rect.x() + listItemPadding, opt.rect.y() + centerObj(opt.rect.height(), listItemIconSize), listItemIconSize, listItemIconSize);
+    painter->drawPixmap(iconRect, index.data(Qt::DecorationRole).value<QIcon>().pixmap(listItemIconSize, listItemIconSize));
+
+    // compute rectangle for label/ID and rectangle for status text
+    auto textRect = QRectF(opt.rect);
+    textRect.setX(iconRect.right() + listItemSpacing);
+    textRect.setWidth(textRect.width() - buttonWidth);
+    auto textOption = QTextOption();
+    textOption.setWrapMode(QTextOption::NoWrap);
+    textOption.setAlignment(Qt::AlignRight | Qt::AlignVCenter);
+    auto statusTextRect = painter->boundingRect(textRect, statusText, textOption);
+    textRect.setWidth(textRect.width() - statusTextRect.width());
+
+    // draw label/ID
+    textOption.setAlignment(opt.displayAlignment);
+    setupPainterToDrawViewItemText(painter, opt);
+    painter->drawText(textRect, painter->fontMetrics().elidedText(id, Qt::ElideRight, static_cast<int>(textRect.width())), textOption);
+
+    // draw status text
+    if (const auto color = index.data(statusColorRole).value<QColor>(); color.isValid()) {
+        opt.palette.setColor(QPalette::Text, color);
+    }
+    textOption.setAlignment(Qt::AlignRight);
+    setupPainterToDrawViewItemText(painter, opt);
+    painter->drawText(statusTextRect, statusText, textOption);
+}
+
 } // namespace QtGui
