@@ -4,156 +4,379 @@
 <context>
     <name>QtGui::App</name>
     <message>
-        <location filename="../gui/app.cpp" line="115"/>
-        <source>Not connected to backend. Check app settings for problems.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../gui/app.cpp" line="117"/>
+        <location filename="../gui/quick/app.cpp" line="306"/>
         <source>Waiting for backend …</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/app.cpp" line="162"/>
-        <location filename="../gui/app.cpp" line="171"/>
+        <location filename="../gui/quick/app.cpp" line="402"/>
+        <location filename="../gui/quick/app.cpp" line="411"/>
         <source>Unable to open &quot;%1&quot;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/app.cpp" line="182"/>
+        <location filename="../gui/quick/app.cpp" line="440"/>
         <source>Copied value</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/app.cpp" line="185"/>
+        <location filename="../gui/quick/app.cpp" line="444"/>
         <source>Unable to copy value</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/app.cpp" line="194"/>
+        <location filename="../gui/quick/app.cpp" line="453"/>
         <source>Unable to copy &quot;%1&quot;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/app.cpp" line="196"/>
-        <source>Copied path</source>
+        <location filename="../gui/quick/app.cpp" line="299"/>
+        <source>Backend is starting …</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/app.cpp" line="206"/>
+        <location filename="../gui/quick/app.cpp" line="285"/>
+        <source>Checking for data to import …</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="287"/>
+        <source>Importing configuration …</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="289"/>
+        <source>Exporting configuration …</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="304"/>
+        <source>Not connected to backend.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="309"/>
+        <source>Saving configuration …</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message numerus="yes">
+        <location filename="../gui/quick/app.cpp" line="311"/>
+        <source>There are %n notification(s)/error(s).</source>
+        <translation>
+            <numerusform>There is %n notification/error.</numerusform>
+            <numerusform>There are %n notifications/errors.</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <location filename="../gui/quick/app.cpp" line="313"/>
+        <source>There are %n Syncthing API error(s).</source>
+        <translation>
+            <numerusform>There is %n Syncthing API error.</numerusform>
+            <numerusform>There are %n Syncthing API errors.</numerusform>
+        </translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="428"/>
+        <source>Scanning is not supported.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="472"/>
         <source>Unable to load ignore patterns: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/app.cpp" line="227"/>
+        <location filename="../gui/quick/app.cpp" line="493"/>
         <source>Unable to save ignore patterns: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/app.cpp" line="351"/>
+        <location filename="../gui/quick/app.cpp" line="861"/>
         <source>Unable to resolve URL &quot;%1&quot;.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/app.cpp" line="378"/>
+        <location filename="../gui/quick/app.cpp" line="1066"/>
+        <source>Syncthing API error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1066"/>
+        <source>%1 Syncthing API errors</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1051"/>
+        <location filename="../gui/quick/app.cpp" line="1067"/>
+        <source>most recent: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1050"/>
+        <source>Syncthing error/notification</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1050"/>
+        <source>%1 Syncthing errors/notifications</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1076"/>
+        <source>Syncthing device wants to connect</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1086"/>
+        <source>Syncthing device wants to share folder</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1166"/>
+        <source>Another config change is still pending.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1277"/>
+        <source>Unable to minimize app.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1324"/>
         <source>Unable to create settings directory under &quot;%1&quot;.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/app.cpp" line="387"/>
+        <location filename="../gui/quick/app.cpp" line="1313"/>
         <source>Unable to open settings under &quot;%1&quot;: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/app.cpp" line="402"/>
+        <location filename="../gui/quick/app.cpp" line="215"/>
+        <source>Triggered override of &quot;%1&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="217"/>
+        <source>Triggered revert of &quot;%1&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="291"/>
+        <source>Checking locations to move home directory …</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="293"/>
+        <source>Moving home directory …</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1343"/>
         <source>Unable to read settings: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/app.cpp" line="406"/>
+        <location filename="../gui/quick/app.cpp" line="1346"/>
         <source>Unable to restore settings: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/app.cpp" line="407"/>
+        <location filename="../gui/quick/app.cpp" line="1347"/>
         <source>JSON document contains no object</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/app.cpp" line="427"/>
+        <location filename="../gui/quick/app.cpp" line="1378"/>
         <source>Unable to save settings: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/app.cpp" line="446"/>
+        <location filename="../gui/quick/app.cpp" line="1406"/>
         <source>Unable to load HTTPs certificate</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/app.cpp" line="474"/>
+        <location filename="../gui/quick/app.cpp" line="1474"/>
         <source>This build of the app cannot launch Syncthing.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/app.cpp" line="482"/>
+        <location filename="../gui/quick/app.cpp" line="1499"/>
+        <source>Persistent logging disabled and logfile removed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1501"/>
+        <source>Unable to remove logfile</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1509"/>
+        <source>Another import/export still pending</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1562"/>
+        <source>The Syncthing home directory under &quot;%1&quot; is empty.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1575"/>
+        <source>No Syncthing configuration file found under &quot;%1&quot;.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1633"/>
+        <location filename="../gui/quick/app.cpp" line="1878"/>
         <source>Unable to import settings: settings directory was not located.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/app.cpp" line="490"/>
+        <location filename="../gui/quick/app.cpp" line="1640"/>
+        <source>Waiting for backend to terminate before importing settings …</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1674"/>
+        <source>Imported app config from &quot;%1&quot;.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1687"/>
+        <source>Imported Syncthing config and database from &quot;%1&quot;.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1705"/>
+        <source>Unable to find folders/devices in current Syncthing config.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1720"/>
+        <source>Merging %1 folders and %2 devices</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1722"/>
+        <source>Unable to import folders/devices.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1740"/>
         <source>Unable to import settings: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/app.cpp" line="493"/>
-        <source>Settings have been imported from &quot;%1&quot;.</source>
+        <location filename="../gui/quick/app.cpp" line="1767"/>
+        <source>unable to create export directory under &quot;%1&quot;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/app.cpp" line="503"/>
-        <source>Unable to create export directory under &quot;%1&quot;.</source>
+        <location filename="../gui/quick/app.cpp" line="1770"/>
+        <source>settings directory was not located.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/app.cpp" line="507"/>
-        <source>Unable to export settings: settings directory was not located.</source>
+        <location filename="../gui/quick/app.cpp" line="1827"/>
+        <source>Default directory</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/app.cpp" line="514"/>
+        <location filename="../gui/quick/app.cpp" line="1843"/>
+        <source>External storage %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1852"/>
+        <source>Current home directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1884"/>
+        <source>Waiting for backend to terminate before moving home …</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1904"/>
+        <source>Home directory stays the same.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1915"/>
+        <source>Cleaned up new home directory &quot;%1&quot;.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1921"/>
+        <source>Copied data from previous home directory &quot;%1&quot; to new one.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1924"/>
+        <source>Cleaned up previous home directory.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1927"/>
+        <source>Configured &quot;%1&quot; as new/empty Syncthing home.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1929"/>
+        <source>Configured &quot;%1&quot; as Syncthing home.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1933"/>
+        <source>Unable to move home directory: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1728"/>
+        <source>Nothing has been imported.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/quick/app.cpp" line="1790"/>
         <source>Unable to export settings: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/app.cpp" line="517"/>
+        <location filename="../gui/quick/app.cpp" line="1783"/>
         <source>Settings have been exported to &quot;%1&quot;.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../gui/quick/app.h" line="155"/>
+        <source>not available</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QtGui::DevView</name>
     <message>
-        <location filename="../gui/devview.cpp" line="66"/>
+        <location filename="../gui/devview.cpp" line="65"/>
         <source>Copy value</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/devview.cpp" line="72"/>
+        <location filename="../gui/devview.cpp" line="71"/>
         <source>Copy name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/devview.cpp" line="75"/>
+        <location filename="../gui/devview.cpp" line="74"/>
         <source>Copy ID</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/devview.cpp" line="81"/>
+        <location filename="../gui/devview.cpp" line="80"/>
         <source>Resume</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/devview.cpp" line="86"/>
+        <location filename="../gui/devview.cpp" line="85"/>
         <source>Pause</source>
         <translation type="unfinished"></translation>
     </message>
@@ -161,47 +384,47 @@
 <context>
     <name>QtGui::DirView</name>
     <message>
-        <location filename="../gui/dirview.cpp" line="78"/>
+        <location filename="../gui/dirview.cpp" line="77"/>
         <source>Copy value</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/dirview.cpp" line="84"/>
+        <location filename="../gui/dirview.cpp" line="83"/>
         <source>Copy label/ID</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/dirview.cpp" line="87"/>
+        <location filename="../gui/dirview.cpp" line="86"/>
         <source>Copy path</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/dirview.cpp" line="92"/>
+        <location filename="../gui/dirview.cpp" line="91"/>
         <source>Rescan</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/dirview.cpp" line="97"/>
+        <location filename="../gui/dirview.cpp" line="96"/>
         <source>Resume</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/dirview.cpp" line="102"/>
+        <location filename="../gui/dirview.cpp" line="101"/>
         <source>Pause</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/dirview.cpp" line="106"/>
+        <location filename="../gui/dirview.cpp" line="105"/>
         <source>Open in file browser</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/dirview.cpp" line="110"/>
+        <location filename="../gui/dirview.cpp" line="109"/>
         <source>Browse remote files</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/dirview.cpp" line="112"/>
+        <location filename="../gui/dirview.cpp" line="111"/>
         <source>Show/edit ignore patterns</source>
         <translation type="unfinished"></translation>
     </message>
@@ -287,7 +510,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/trayicon.cpp" line="304"/>
+        <location filename="../gui/trayicon.cpp" line="305"/>
         <source>New Syncthing folder - click for web UI</source>
         <translation type="unfinished"></translation>
     </message>
@@ -300,126 +523,126 @@
 <context>
     <name>QtGui::TrayWidget</name>
     <message>
-        <location filename="../gui/traywidget.ui" line="6"/>
+        <location filename="../gui/traywidget.ui" line="11"/>
         <source>Syncthing Tray</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="99"/>
+        <location filename="../gui/traywidget.ui" line="104"/>
         <location filename="../gui/traywidget.cpp" line="351"/>
         <source>About</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="58"/>
+        <location filename="../gui/traywidget.ui" line="63"/>
         <location filename="../gui/traywidget.cpp" line="472"/>
         <source>Connect</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="72"/>
-        <location filename="../gui/traywidget.cpp" line="904"/>
-        <location filename="../gui/traywidget.cpp" line="946"/>
+        <location filename="../gui/traywidget.ui" line="77"/>
+        <location filename="../gui/traywidget.cpp" line="906"/>
+        <location filename="../gui/traywidget.cpp" line="948"/>
         <source>Start</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="113"/>
+        <location filename="../gui/traywidget.ui" line="118"/>
         <source>Settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="127"/>
+        <location filename="../gui/traywidget.ui" line="132"/>
         <source>Open Syncthing</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="289"/>
+        <location filename="../gui/traywidget.ui" line="294"/>
         <source>In</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="296"/>
+        <location filename="../gui/traywidget.ui" line="301"/>
         <source>Incoming traffic</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="228"/>
-        <location filename="../gui/traywidget.ui" line="248"/>
-        <location filename="../gui/traywidget.ui" line="299"/>
-        <location filename="../gui/traywidget.ui" line="319"/>
+        <location filename="../gui/traywidget.ui" line="233"/>
+        <location filename="../gui/traywidget.ui" line="253"/>
+        <location filename="../gui/traywidget.ui" line="304"/>
+        <location filename="../gui/traywidget.ui" line="324"/>
         <source>unknown</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="218"/>
+        <location filename="../gui/traywidget.ui" line="223"/>
         <source>Global</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="225"/>
+        <location filename="../gui/traywidget.ui" line="230"/>
         <source>Global overall statistics</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="235"/>
+        <location filename="../gui/traywidget.ui" line="240"/>
         <source>Local</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="245"/>
+        <location filename="../gui/traywidget.ui" line="250"/>
         <source>Local overall statistics</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="306"/>
+        <location filename="../gui/traywidget.ui" line="311"/>
         <source>Out</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="316"/>
+        <location filename="../gui/traywidget.ui" line="321"/>
         <source>Outgoing traffic</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="350"/>
+        <location filename="../gui/traywidget.ui" line="355"/>
         <source>Click to show &lt;i&gt;new&lt;/i&gt; notifications&lt;br&gt;
 For &lt;i&gt;all&lt;/i&gt; notifications, checkout the log</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="357"/>
+        <location filename="../gui/traywidget.ui" line="362"/>
         <location filename="../gui/traywidget.cpp" line="161"/>
         <source>New notifications</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="388"/>
+        <location filename="../gui/traywidget.ui" line="392"/>
         <source>Folders</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="421"/>
+        <location filename="../gui/traywidget.ui" line="425"/>
         <source>Devices</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="454"/>
+        <location filename="../gui/traywidget.ui" line="491"/>
         <source>Downloads</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="483"/>
+        <location filename="../gui/traywidget.ui" line="458"/>
         <source>Recent changes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="519"/>
+        <location filename="../gui/traywidget.ui" line="523"/>
         <source>Show</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="529"/>
+        <location filename="../gui/traywidget.ui" line="533"/>
         <source>Dismiss</source>
         <translation type="unfinished"></translation>
     </message>
@@ -484,22 +707,22 @@ For &lt;i&gt;all&lt;/i&gt; notifications, checkout the log</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="486"/>
+        <location filename="../gui/traywidget.cpp" line="487"/>
         <source>Pause</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="487"/>
+        <location filename="../gui/traywidget.cpp" line="488"/>
         <source>Syncthing is running, click to pause all devices</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="492"/>
+        <location filename="../gui/traywidget.cpp" line="493"/>
         <source>Continue</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="493"/>
+        <location filename="../gui/traywidget.cpp" line="494"/>
         <source>At least one device is paused, click to resume</source>
         <translation type="unfinished"></translation>
     </message>
@@ -509,48 +732,48 @@ For &lt;i&gt;all&lt;/i&gt; notifications, checkout the log</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="689"/>
+        <location filename="../gui/traywidget.cpp" line="690"/>
         <source>The folder &lt;i&gt;%1&lt;/i&gt; does not exist on the local machine.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="700"/>
+        <location filename="../gui/traywidget.cpp" line="701"/>
         <source>The containing folder &lt;i&gt;%1&lt;/i&gt; does not exist on the local machine.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="760"/>
+        <location filename="../gui/traywidget.cpp" line="761"/>
         <source>Open item</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="765"/>
+        <location filename="../gui/traywidget.cpp" line="766"/>
         <source>Copy path</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="769"/>
+        <location filename="../gui/traywidget.cpp" line="770"/>
         <source>Copy device ID</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="772"/>
+        <location filename="../gui/traywidget.cpp" line="773"/>
         <source>Copy folder ID</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="900"/>
-        <location filename="../gui/traywidget.cpp" line="940"/>
+        <location filename="../gui/traywidget.cpp" line="902"/>
+        <location filename="../gui/traywidget.cpp" line="942"/>
         <source>Stop</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="901"/>
+        <location filename="../gui/traywidget.cpp" line="903"/>
         <source>Stop Syncthing instance launched via tray icon</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="905"/>
+        <location filename="../gui/traywidget.cpp" line="907"/>
         <source>Start Syncthing with the built-in launcher configured in the settings</source>
         <translation type="unfinished"></translation>
     </message>
@@ -558,17 +781,17 @@ For &lt;i&gt;all&lt;/i&gt; notifications, checkout the log</source>
 <context>
     <name>main</name>
     <message>
-        <location filename="../application/main.cpp" line="90"/>
+        <location filename="../application/main.cpp" line="98"/>
         <source>Unable to </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../application/main.cpp" line="125"/>
+        <location filename="../application/main.cpp" line="133"/>
         <source>The system tray is (currently) not available. You could open the tray menu as a regular window using the --windowed flag, though.It is also possible to start Syncthing Tray with --wait to wait until the system tray becomes available instead of showing this message.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../application/main.cpp" line="152"/>
+        <location filename="../application/main.cpp" line="160"/>
         <source>The Qt libraries have not been built with tray icon support. You could open the tray menu as a regular window using the -w flag, though.</source>
         <translation type="unfinished"></translation>
     </message>
